module Unicode2LaTeX
  class << self

    #https://pastebin.com/Q4VkkNr1

    SYMBOLS = {
      "𝐴":                           "A",
      "𝐵":                           "B",
      "𝐶":                           "C",
      "𝐷":                           "D",
      "𝐸":                           "E",
      "𝐹":                           "F",
      "𝐺":                           "G",
      "𝐻":                           "H",
      "𝐼":                           "I",
      "𝐽":                           "J",
      "𝐾":                           "K",
      "𝐿":                           "L",
      "𝑀":                           "M",
      "𝑁":                           "N",
      "𝑂":                           "O",
      "𝑃":                           "P",
      "𝑄":                           "Q",
      "𝑅":                           "R",
      "𝑆":                           "S",
      "𝑇":                           "T",
      "𝑈":                           "U",
      "𝑉":                           "V",
      "𝑊":                           "W",
      "𝑋":                           "X",
      "𝑌":                           "Y",
      "𝑍":                           "Z",
      "𝑎":                           "a",
      "𝑏":                           "b",
      "𝑐":                           "c",
      "𝑑":                           "d",
      "𝑒":                           "e",
      "𝑓":                           "f",
      "𝑔":                           "g",
      "h":                           "h",
      "𝑖":                           "i",
      "𝑗":                           "j",
      "𝑘":                           "k",
      "𝑙":                           "l",
      "𝑚":                           "m",
      "𝑛":                           "n",
      "𝑜":                           "o",
      "𝑝":                           "p",
      "𝑞":                           "q",
      "𝑟":                           "r",
      "𝑠":                           "s",
      "𝑡":                           "t",
      "𝑢":                           "u",
      "𝑣":                           "v",
      "𝑤":                           "w",
      "𝑥":                           "x",
      "𝑦":                           "y",
      "𝑧":                           "z",
      "~":                           "~",
      "¢":                      "\\cent",
      "£":                    "\\pounds",
      "¥":                       "\\yen",
      "¨":                    "\\spddot",
      "¬":                      "\\lnot",
      "®":                  "\\circledR",
      "±":                        "\\pm",
      "µ":                     "\\Micro",
      "·":                     "\\cdotp",
      "×":                     "\\times",
      "ð":                       "\\eth",
      "÷":                       "\\div",
      "𝚤":                     "\\imath",
      "Ƶ":                      "\\Zbar",
      "𝚥":                     "\\jmath",
      "̀":                     "\\grave",
      "́":                     "\\acute",
      "̂":                       "\\hat",
      "̃":                     "\\tilde",
      "̄":                       "\\bar",
      "̅":                  "\\overline",
      "̆":                     "\\breve",
      "̇":                       "\\dot",
      "̈":                      "\\ddot",
      "̉":                    "\\ovhook",
      "̊":                  "\\mathring",
      "̌":                     "\\check",
      "̐":                    "\\candra",
      "̒":              "\\oturnedcomma",
      "̕":            "\\ocommatopright",
      "̚":                    "\\droang",
      "̰":                    "\\utilde",
      "̱":                  "\\underbar",
      "̲":                 "\\underline",
      "̸":                       "\\not",
      " ":                      "\\quad",
      "―":                  "\\horizbar",
      "‖":                         "\\|",
      "‗":                "\\twolowline",
      "†":                    "\\dagger",
      "‡":                   "\\ddagger",
      "•":               "\\smblkcircle",
      "‥":           "\\enleadertwodots",
      "…":                     "\\ldots",
      "′":                     "\\prime",
      "″":                    "\\second",
      "‴":                     "\\third",
      "‵":                 "\\backprime",
      "‶":                "\\backdprime",
      "‷":               "\\backtrprime",
      "‸":               "\\caretinsert",
      "‼":                    "\\Exclam",
      "⁀":                       "\\cat",
      "⁃":              "\\hyphenbullet",
      "⁄":                 "\\fracslash",
      "⁇":                  "\\Question",
      "⁐":                   "\\closure",
      "⁗":                    "\\fourth",
      " ":                         "\\:",
      "€":                      "\\euro",
      "⃐":                      "\\lvec",
      "⃗":                       "\\vec",
      "⃒":               "\\vertoverlay",
      "⃖":                      "\\LVec",
      "⃛":                     "\\dddot",
      "⃜":                    "\\ddddot",
      "⃝":             "\\enclosecircle",
      "⃞":             "\\enclosesquare",
      "⃟":            "\\enclosediamond",
      "⃡":        "\\overleftrightarrow",
      "⃤":           "\\enclosetriangle",
      "⃧":                   "\\annuity",
      "⃨":             "\\threeunderdot",
      "⃩":           "\\widebridgeabove",
      "⃬":     "\\underrightharpoondown",
      "⃭":      "\\underleftharpoondown",
      "⃮":            "\\underleftarrow",
      "⃯":           "\\underrightarrow",
      "⃰":               "\\asteraccent",
      "ℂ":                 "\\mathbb{C}",
      "ℇ":                     "\\Euler",
      "ℊ":                "\\mathcal{g}",
      "ℋ":                "\\mathcal{H}",
      "ℌ":               "\\mathfrak{H}",
      "ℍ":                 "\\mathbb{H}",
      "ℎ":               "\\Planckconst",
      "ℏ":                    "\\hslash",
      "ℐ":                "\\mathcal{I}",
      "ℑ":                        "\\Im",
      "ℒ":                "\\mathcal{L}",
      "ℓ":                       "\\ell",
      "ℕ":                 "\\mathbb{N}",
      "℘":                        "\\wp",
      "ℙ":                 "\\mathbb{P}",
      "ℚ":                 "\\mathbb{Q}",
      "ℛ":                "\\mathcal{R}",
      "ℜ":                        "\\Re",
      "ℝ":                 "\\mathbb{R}",
      "ℤ":                 "\\mathbb{Z}",
      "Ω":                     "\\tcohm",
      "℧":                       "\\mho",
      "ℨ":               "\\mathfrak{Z}",
      "℩":                "\\turnediota",
      "Å":                 "\\Angstroem",
      "ℬ":                "\\mathcal{B}",
      "ℭ":               "\\mathfrak{C}",
      "ℯ":                "\\mathcal{e}",
      "ℰ":                "\\mathcal{E}",
      "ℱ":                "\\mathcal{F}",
      "Ⅎ":                      "\\Finv",
      "ℳ":                "\\mathcal{M}",
      "ℴ":                "\\mathcal{o}",
      "ℵ":                     "\\aleph",
      "ℶ":                      "\\beth",
      "ℷ":                     "\\gimel",
      "ℸ":                    "\\daleth",
      "ℼ":              "\\mathbb{\\pi}",
      "ℽ":           "\\mathbb{\\gamma}",
      "ℾ":           "\\mathbb{\\Gamma}",
      "ℿ":              "\\mathbb{\\Pi}",
      "⅀":           "\\mathbb{\\Sigma}",
      "⅁":                      "\\Game",
      "⅂":               "\\sansLturned",
      "⅃":             "\\sansLmirrored",
      "⅄":                       "\\Yup",
      "ⅅ":      "\\CapitalDifferentialD",
      "ⅆ":             "\\DifferentialD",
      "ⅇ":               "\\ExponetialE",
      "ⅈ":                  "\\ComplexI",
      "ⅉ":                  "\\ComplexJ",
      "⅊":              "\\PropertyLine",
      "⅋":                    "\\invamp",
      "←":                 "\\leftarrow",
      "↑":                   "\\uparrow",
      "→":                "\\rightarrow",
      "↓":                 "\\downarrow",
      "↔":            "\\leftrightarrow",
      "↕":               "\\updownarrow",
      "↖":                   "\\nwarrow",
      "↗":                   "\\nearrow",
      "↘":                   "\\searrow",
      "↙":                   "\\swarrow",
      "↚":                "\\nleftarrow",
      "↛":               "\\nrightarrow",
      "↜":             "\\leftwavearrow",
      "↝":            "\\rightwavearrow",
      "↞":          "\\twoheadleftarrow",
      "↟":            "\\twoheaduparrow",
      "↠":         "\\twoheadrightarrow",
      "↡":          "\\twoheaddownarrow",
      "↢":             "\\leftarrowtail",
      "↣":            "\\rightarrowtail",
      "↤":                  "\\mapsfrom",
      "↥":                    "\\MapsUp",
      "↦":                    "\\mapsto",
      "↧":                  "\\MapsDown",
      "↨":            "\\updownarrowbar",
      "↩":             "\\hookleftarrow",
      "↪":            "\\hookrightarrow",
      "↫":             "\\looparrowleft",
      "↬":            "\\looparrowright",
      "↭":       "\\leftrightsquigarrow",
      "↮":           "\\nleftrightarrow",
      "↯":                 "\\lightning",
      "↰":                       "\\Lsh",
      "↱":                       "\\Rsh",
      "↲":                      "\\dlsh",
      "↳":                      "\\drsh",
      "↴":                  "\\linefeed",
      "↵":            "\\carriagereturn",
      "↶":            "\\curvearrowleft",
      "↷":           "\\curvearrowright",
      "↸":     "\\barovernorthwestarrow",
      "↺":           "\\circlearrowleft",
      "↻":          "\\circlearrowright",
      "↼":             "\\leftharpoonup",
      "↽":           "\\leftharpoondown",
      "↾":            "\\upharpoonright",
      "↿":             "\\upharpoonleft",
      "⇀":            "\\rightharpoonup",
      "⇁":          "\\rightharpoondown",
      "⇂":          "\\downharpoonright",
      "⇃":           "\\downharpoonleft",
      "⇄":           "\\rightleftarrows",
      "⇅":              "\\updownarrows",
      "⇆":           "\\leftrightarrows",
      "⇇":            "\\leftleftarrows",
      "⇈":                "\\upuparrows",
      "⇉":          "\\rightrightarrows",
      "⇊":            "\\downdownarrows",
      "⇋":         "\\leftrightharpoons",
      "⇌":         "\\rightleftharpoons",
      "⇍":                "\\nLeftarrow",
      "⇎":           "\\nLeftrightarrow",
      "⇏":               "\\nRightarrow",
      "⇐":                 "\\Leftarrow",
      "⇑":                   "\\Uparrow",
      "⇒":                "\\Rightarrow",
      "⇓":                 "\\Downarrow",
      "⇔":            "\\Leftrightarrow",
      "⇕":               "\\Updownarrow",
      "⇖":                   "\\Nwarrow",
      "⇗":                   "\\Nearrow",
      "⇘":                   "\\Searrow",
      "⇙":                   "\\Swarrow",
      "⇚":                "\\Lleftarrow",
      "⇛":               "\\Rrightarrow",
      "⇜":            "\\leftsquigarrow",
      "⇝":           "\\rightsquigarrow",
      "⇞":                 "\\nHuparrow",
      "⇟":               "\\nHdownarrow",
      "⇠":             "\\dashleftarrow",
      "⇡":               "\\updasharrow",
      "⇢":            "\\dashrightarrow",
      "⇣":             "\\downdasharrow",
      "⇤":              "\\LeftArrowBar",
      "⇥":             "\\RightArrowBar",
      "⇦":            "\\leftwhitearrow",
      "⇧":              "\\upwhitearrow",
      "⇨":           "\\rightwhitearrow",
      "⇩":            "\\downwhitearrow",
      "⇪":       "\\whitearrowupfrombar",
      "⍹":                   "\\mathord",
      "⇴":        "\\circleonrightarrow",
      "⇵":              "\\downuparrows",
      "⇶":          "\\rightthreearrows",
      "⇷":               "\\nvleftarrow",
      "⇸":                      "\\pfun",
      "⇹":          "\\nvleftrightarrow",
      "⇺":               "\\nVleftarrow",
      "⇻":                      "\\ffun",
      "⇼":          "\\nVleftrightarrow",
      "⇽":         "\\leftarrowtriangle",
      "⇾":        "\\rightarrowtriangle",
      "⇿":    "\\leftrightarrowtriangle",
      "∀":                    "\\forall",
      "∁":                "\\complement",
      "𝜕":                   "\\partial",
      "∃":                    "\\exists",
      "∄":                   "\\nexists",
      "∅":                  "\\emptyset",
      "∆":                 "\\increment",
      "∇":                     "\\nabla",
      "∈":                        "\\in",
      "∉":                     "\\notin",
      "∊":                   "\\smallin",
      "∋":                        "\\ni",
      "∌":                       "\\nni",
      "∍":                   "\\smallni",
      "∎":                       "\\QED",
      "∏":                      "\\prod",
      "∐":                    "\\coprod",
      "∑":                       "\\sum",
      "−":                           "-",
      "∓":                        "\\mp",
      "∔":                   "\\dotplus",
      "∕":                     "\\slash",
      "∖":             "\\smallsetminus",
      "∗":                       "\\ast",
      "∘":                      "\\circ",
      "∙":                    "\\bullet",
      "√":                      "\\sqrt",
      "∛":                   "\\sqrt[3]",
      "∜":                   "\\sqrt[4]",
      "∝":                    "\\propto",
      "∞":                     "\\infty",
      "∟":                "\\rightangle",
      "∠":                     "\\angle",
      "∡":             "\\measuredangle",
      "∢":            "\\sphericalangle",
      "∣":                       "\\mid",
      "∤":                      "\\nmid",
      "∥":                  "\\parallel",
      "∦":                 "\\nparallel",
      "∧":                      "\\land",
      "∨":                       "\\lor",
  "∩":                       "\\cap",
  "∪":                       "\\cup",
  "∫":                       "\\int",
  "∬":                      "\\iint",
  "∭":                     "\\iiint",
  "∮":                      "\\oint",
  "∯":                     "\\oiint",
  "∰":                    "\\oiiint",
  "∱":              "\\intclockwise",
  "∲":          "\\varointclockwise",
  "∳":          "\\ointctrclockwise",
  "∴":                 "\\therefore",
  "∵":                   "\\because",
  "∷":                "\\Proportion",
  "∸":                  "\\dotminus",
  "≕":                   "\\eqcolon",
  "∺":             "\\dotsminusdots",
  "∻":         "\\kernelcontraction",
  "∼":                       "\\sim",
  "∽":                   "\\backsim",
  "∾":                  "\\invlazys",
  "∿":                        "\\AC",
  "≀":                        "\\wr",
  "≁":                      "\\nsim",
  "≂":                     "\\eqsim",
  "≃":                     "\\simeq",
  "≄":                    "\\nsimeq",
  "≅":                      "\\cong",
  "≆":                   "\\simneqq",
  "≇":                     "\\ncong",
  "≈":                    "\\approx",
  "≉":                   "\\napprox",
  "≊":                  "\\approxeq",
  "≋":               "\\approxident",
  "≌":                  "\\backcong",
  "≍":                     "\\asymp",
  "≎":                    "\\Bumpeq",
  "≏":                    "\\bumpeq",
  "≐":                     "\\doteq",
  "≑":                     "\\Doteq",
  "≒":             "\\fallingdotseq",
  "≓":              "\\risingdotseq",
  "≔":                   "\\coloneq",
  "≖":                    "\\eqcirc",
  "≗":                    "\\circeq",
  "≘":                     "\\arceq",
  "≙":               "\\corresponds",
  "≚":                     "\\veeeq",
  "≛":                    "\\stareq",
  "≜":                 "\\triangleq",
  "≝":                     "\\eqdef",
  "≞":                    "\\measeq",
  "≟":                   "\\questeq",
  "≠":                       "\\neq",
  "≡":                     "\\equiv",
  "≢":                    "\\nequiv",
  "≣":                     "\\Equiv",
  "≤":                       "\\leq",
  "≥":                       "\\geq",
  "≦":                      "\\leqq",
  "≧":                      "\\geqq",
  "≨":                     "\\lneqq",
  "≩":                     "\\gneqq",
  "≪":                        "\\ll",
  "≫":                        "\\gg",
  "≬":                   "\\between",
  "≭":                  "\\notasymp",
  "≮":                     "\\nless",
  "≯":                      "\\ngtr",
  "≰":                      "\\nleq",
  "≱":                      "\\ngeq",
  "≲":                   "\\lesssim",
  "≳":                    "\\gtrsim",
  "≴":              "\\NotLessTilde",
  "≵":           "\\NotGreaterTilde",
  "≶":                   "\\lessgtr",
  "≷":                   "\\gtrless",
  "≸":                  "\\nlessgtr",
  "≹":            "\\NotGreaterLess",
  "≺":                      "\\prec",
  "≻":                      "\\succ",
  "≼":               "\\preccurlyeq",
  "≽":               "\\succcurlyeq",
  "≾":                   "\\precsim",
  "≿":                   "\\succsim",
  "⊀":                     "\\nprec",
  "⊁":                     "\\nsucc",
  "⊂":                    "\\subset",
  "⊃":                    "\\supset",
  "⊄":                   "\\nsubset",
  "⊅":                   "\\nsupset",
  "⊆":                  "\\subseteq",
  "⊇":                  "\\supseteq",
  "⊈":                 "\\nsubseteq",
  "⊉":                 "\\nsupseteq",
  "⊊":                 "\\subsetneq",
  "⊋":                 "\\supsetneq",
  "⊌":              "\\cupleftarrow",
  "⊍":                    "\\cupdot",
  "⊎":                     "\\uplus",
  "⊏":                  "\\sqsubset",
  "⊐":                  "\\sqsupset",
  "⊑":                "\\sqsubseteq",
  "⊒":                "\\sqsupseteq",
  "⊓":                     "\\sqcap",
  "⊔":                     "\\sqcup",
  "⊕":                     "\\oplus",
  "⊖":                    "\\ominus",
  "⊗":                    "\\otimes",
  "⊘":                    "\\oslash",
  "⊙":                      "\\odot",
  "⊚":               "\\circledcirc",
  "⊛":                "\\circledast",
  "⊜":              "\\circledequal",
  "⊝":               "\\circleddash",
  "⊞":                   "\\boxplus",
  "⊟":                  "\\boxminus",
  "⊠":                  "\\boxtimes",
  "⊡":                    "\\boxdot",
  "⊢":                     "\\vdash",
  "⊣":                     "\\dashv",
  "⊤":                       "\\top",
  "⊥":                       "\\bot",
  "⊦":                    "\\assert",
  "⊧":                    "\\models",
  "⊨":                     "\\vDash",
  "⊩":                     "\\Vdash",
  "⊪":                    "\\Vvdash",
  "⊫":                     "\\VDash",
  "⊬":                    "\\nvdash",
  "⊭":                    "\\nvDash",
  "⊮":                    "\\nVdash",
  "⊯":                    "\\nVDash",
  "⊰":                    "\\prurel",
  "⊱":                    "\\scurel",
  "⊲":           "\\vartriangleleft",
  "⊳":          "\\vartriangleright",
  "⊴":            "\\trianglelefteq",
  "⊵":           "\\trianglerighteq",
  "⊶":          "\\multimapdotbothA",
  "⊷":          "\\multimapdotbothB",
  "⊸":                  "\\multimap",
  "⊹":              "\\hermitmatrix",
  "⊺":                  "\\intercal",
  "⊻":                    "\\veebar",
  "⊼":                  "\\barwedge",
  "⊽":                    "\\barvee",
  "⊾":        "\\measuredrightangle",
  "⊿":             "\\varlrtriangle",
  "⋀":                  "\\bigwedge",
  "⋁":                    "\\bigvee",
  "⋂":                    "\\bigcap",
  "⋃":                    "\\bigcup",
  "⋄":                   "\\diamond",
  "⋅":                      "\\cdot",
  "⋆":                      "\\star",
  "⋇":             "\\divideontimes",
  "⋈":                    "\\bowtie",
  "⋉":                    "\\ltimes",
  "⋊":                    "\\rtimes",
  "⋋":            "\\leftthreetimes",
  "⋌":           "\\rightthreetimes",
  "⋍":                 "\\backsimeq",
  "⋎":                  "\\curlyvee",
  "⋏":                "\\curlywedge",
  "⋐":                    "\\Subset",
  "⋑":                    "\\Supset",
  "⋒":                       "\\Cap",
  "⋓":                       "\\Cup",
  "⋔":                 "\\pitchfork",
  "⋕":                      "\\hash",
  "⋖":                   "\\lessdot",
  "⋗":                    "\\gtrdot",
  "⋘":                       "\\lll",
  "⋙":                       "\\ggg",
  "⋚":                 "\\lesseqgtr",
  "⋛":                 "\\gtreqless",
  "⋜":                    "\\eqless",
  "⋝":                     "\\eqgtr",
  "⋞":               "\\curlyeqprec",
  "⋟":               "\\curlyeqsucc",
  "⋠":                   "\\npreceq",
  "⋡":                   "\\nsucceq",
  "⋢":               "\\nsqsubseteq",
  "⋣":               "\\nsqsupseteq",
  "⋤":               "\\sqsubsetneq",
  "⋥":               "\\sqsupsetneq",
  "⋦":                     "\\lnsim",
  "⋧":                     "\\gnsim",
  "⋨":                  "\\precnsim",
  "⋩":                  "\\succnsim",
  "⋪":             "\\ntriangleleft",
  "⋫":            "\\ntriangleright",
  "⋬":           "\\ntrianglelefteq",
  "⋭":          "\\ntrianglerighteq",
  "⋮":                     "\\vdots",
  "⋯":                     "\\cdots",
  "⋰":                    "\\iddots",
  "⋱":                     "\\ddots",
  "⋲":                     "\\disin",
  "⋳":                  "\\varisins",
  "⋴":                     "\\isins",
  "⋵":                   "\\isindot",
  "⋶":                     "\\barin",
  "⋷":                  "\\isinobar",
  "⋸":                    "\\isinvb",
  "⋹":                     "\\isinE",
  "⋺":                      "\\nisd",
  "⋻":                    "\\varnis",
  "⋼":                       "\\nis",
  "⋽":                 "\\varniobar",
  "⋾":                    "\\niobar",
  "⋿":                 "\\bagmember",
  "⌀":                  "\\diameter",
  "⌂":                     "\\house",
  "⌅":               "\\varbarwedge",
  "⌆":         "\\vardoublebarwedge",
  "⌈":                     "\\lceil",
  "⌉":                     "\\rceil",
  "⌊":                    "\\lfloor",
  "⌋":                    "\\rfloor",
  "⌐":                    "\\invneg",
  "⌑":               "\\wasylozenge",
  "⌒":                  "\\profline",
  "⌓":                  "\\profsurf",
  "⌗":                  "\\viewdata",
  "⌙":                 "\\turnednot",
  "⌜":                  "\\ulcorner",
  "⌝":                  "\\urcorner",
  "⌞":                  "\\llcorner",
  "⌟":                  "\\lrcorner",
  "⌠":                    "\\inttop",
  "⌡":                 "\\intbottom",
  "⌢":                     "\\frown",
  "⌣":                     "\\smile",
  "⌬":         "\\varhexagonlrbonds",
  "⌲":                "\\conictaper",
  "⌶":                    "\\topbot",
  "⌹":                    "\\APLinv",
  "⌽":                      "\\obar",
  "⌿":                  "\\notslash",
  "⍀":              "\\notbackslash",
  "⍇":           "\\APLleftarrowbox",
  "⍈":          "\\APLrightarrowbox",
  "⍐":             "\\APLuparrowbox",
  "⍓":             "\\APLboxupcaret",
  "⍗":           "\\APLdownarrowbox",
  "⍝":                "\\APLcomment",
  "⍞":                  "\\APLinput",
  "⍟":                    "\\APLlog",
  "⍰":            "\\APLboxquestion",
  "⍼":     "\\rangledownzigzagarrow",
  "⎔":                   "\\hexagon",
  "⎛":                "\\lparenuend",
  "⎜":            "\\lparenextender",
  "⎝":                "\\lparenlend",
  "⎞":                "\\rparenuend",
  "⎟":            "\\rparenextender",
  "⎠":                "\\rparenlend",
  "⎡":                "\\lbrackuend",
  "⎢":            "\\lbrackextender",
  "⎣":                "\\lbracklend",
  "⎤":                "\\rbrackuend",
  "⎥":            "\\rbrackextender",
  "⎦":                "\\rbracklend",
  "⎧":                "\\lbraceuend",
  "⎨":                 "\\lbracemid",
  "⎩":                "\\lbracelend",
  "⎪":            "\\vbraceextender",
  "⎫":                "\\rbraceuend",
  "⎬":                 "\\rbracemid",
  "⎭":                "\\rbracelend",
  "⎮":               "\\intextender",
  "⎯":            "\\harrowextender",
  "⎰":                "\\lmoustache",
  "⎱":                "\\rmoustache",
  "⎲":                    "\\sumtop",
  "⎳":                 "\\sumbottom",
  "⎴":               "\\overbracket",
  "⎵":              "\\underbracket",
  "⎶":                  "\\bbrktbrk",
  "⎷":                "\\sqrtbottom",
  "⎸":                 "\\lvboxline",
  "⎹":                 "\\rvboxline",
  "⏎":         "\\varcarriagereturn",
  "⏜":                 "\\overparen",
  "⏝":                "\\underparen",
  "⏞":                 "\\overbrace",
  "⏟":                "\\underbrace",
  "⏠":                   "\\obrbrak",
  "⏡":                   "\\ubrbrak",
  "⏢":                 "\\trapezium",
  "⏣":                   "\\benzenr",
  "⏤":                     "\\strns",
  "⏥":                     "\\fltns",
  "⏦":                 "\\accurrent",
  "⏧":                  "\\elinters",
  "┆":             "\\bdtriplevdash",
  "▀":               "\\blockuphalf",
  "▄":              "\\blocklowhalf",
  "█":                 "\\blockfull",
  "▌":             "\\blocklefthalf",
  "▐":            "\\blockrighthalf",
  "░":            "\\blockqtrshaded",
  "▒":           "\\blockhalfshaded",
  "▓":       "\\blockthreeqtrshaded",
  "■":             "\\mdlgblksquare",
  "□":             "\\mdlgwhtsquare",
  "▢":                   "\\squoval",
  "▣":        "\\blackinwhitesquare",
  "▤":               "\\squarehfill",
  "▥":               "\\squarevfill",
  "▦":              "\\squarehvfill",
  "▧":            "\\squarenwsefill",
  "▨":            "\\squareneswfill",
  "▩":           "\\squarecrossfill",
  "▪":               "\\smblksquare",
  "▫":               "\\smwhtsquare",
  "▬":           "\\hrectangleblack",
  "▭":                "\\hrectangle",
  "▮":           "\\vrectangleblack",
  "▯":                "\\vrectangle",
  "▰":        "\\parallelogramblack",
  "▱":             "\\parallelogram",
  "▲":        "\\bigblacktriangleup",
  "△":             "\\bigtriangleup",
  "▴":           "\\blacktriangleup",
  "▵":           "\\smalltriangleup",
  "▶":                       "\\RHD",
  "▷":                       "\\rhd",
  "▸":        "\\blacktriangleright",
  "▹":        "\\smalltriangleright",
  "►":         "\\blackpointerright",
  "▻":         "\\whitepointerright",
  "▼":      "\\bigblacktriangledown",
  "▽":           "\\bigtriangledown",
  "▾":         "\\blacktriangledown",
  "▿":         "\\smalltriangledown",
  "◀":                       "\\LHD",
  "◁":                       "\\lhd",
  "◂":         "\\blacktriangleleft",
  "◃":         "\\smalltriangleleft",
  "◄":          "\\blackpointerleft",
  "◅":          "\\whitepointerleft",
  "◆":              "\\Diamondblack",
  "◇":                   "\\Diamond",
  "◈":       "\\blackinwhitediamond",
  "◉":                   "\\fisheye",
  "◊":                   "\\lozenge",
  "○":                    "\\Circle",
  "◌":              "\\dottedcircle",
  "◍":            "\\circlevertfill",
  "◎":                  "\\bullseye",
  "●":                    "\\CIRCLE",
  "◐":                "\\LEFTcircle",
  "◑":               "\\RIGHTcircle",
  "◒":     "\\circlebottomhalfblack",
  "◓":        "\\circletophalfblack",
  "◔":         "\\circleurquadblack",
  "◕":    "\\blackcircleulquadwhite",
  "◖":                "\\LEFTCIRCLE",
  "◗":               "\\RIGHTCIRCLE",
  "◘":             "\\inversebullet",
  "◙":        "\\inversewhitecircle",
  "◚":   "\\invwhiteupperhalfcircle",
  "◛":   "\\invwhitelowerhalfcircle",
  "◜":                     "\\ularc",
  "◝":                     "\\urarc",
  "◞":                     "\\lrarc",
  "◟":                     "\\llarc",
  "◠":             "\\topsemicircle",
  "◡":             "\\botsemicircle",
  "◢":           "\\lrblacktriangle",
  "◣":           "\\llblacktriangle",
  "◤":           "\\ulblacktriangle",
  "◥":           "\\urblacktriangle",
  "◦":               "\\smwhtcircle",
  "◧":           "\\squareleftblack",
  "◨":          "\\squarerightblack",
  "◩":             "\\squareulblack",
  "◪":             "\\squarelrblack",
  "◫":                    "\\boxbar",
  "◬":              "\\trianglecdot",
  "◭":         "\\triangleleftblack",
  "◮":        "\\trianglerightblack",
  "◯":               "\\lgwhtcircle",
  "◰":              "\\squareulquad",
  "◱":              "\\squarellquad",
  "◲":              "\\squarelrquad",
  "◳":              "\\squareurquad",
  "◴":              "\\circleulquad",
  "◵":              "\\circlellquad",
  "◶":              "\\circlelrquad",
  "◷":              "\\circleurquad",
  "◸":                "\\ultriangle",
  "◹":                "\\urtriangle",
  "◺":                "\\lltriangle",
  "⬜":                    "\\square",
  "⬛":               "\\blacksquare",
  "◽":             "\\mdsmwhtsquare",
  "◾":             "\\mdsmblksquare",
  "◿":                "\\lrtriangle",
  "★":                   "\\bigstar",
  "☆":              "\\bigwhitestar",
  "☉":                       "\\Sun",
  "☐":                    "\\Square",
  "☑":                "\\CheckedBox",
  "☒":                      "\\XBox",
  "☕":                  "\\steaming",
  "☞":                "\\pointright",
  "☠":                     "\\skull",
  "☡":                    "\\danger",
  "☢":                 "\\radiation",
  "☣":                 "\\biohazard",
  "☯":                   "\\yinyang",
  "☹":                   "\\frownie",
  "☺":                    "\\smiley",
  "☻":               "\\blacksmiley",
  "☼":                       "\\sun",
  "☽":                 "\\rightmoon",
  "☾":                  "\\leftmoon",
  "☿":                   "\\mercury",
  "♀":                    "\\female",
  "♁":                     "\\earth",
  "♂":                      "\\male",
  "♃":                   "\\jupiter",
  "♄":                    "\\saturn",
  "♅":                    "\\uranus",
  "♆":                   "\\neptune",
  "♇":                     "\\pluto",
  "♈":                     "\\aries",
  "♉":                    "\\taurus",
  "♊":                    "\\gemini",
  "♋":                    "\\cancer",
  "♌":                       "\\leo",
  "♍":                     "\\virgo",
  "♎":                     "\\libra",
  "♏":                   "\\scorpio",
  "♐":               "\\sagittarius",
  "♑":               "\\capricornus",
  "♒":                  "\\aquarius",
  "♓":                    "\\pisces",
  "♠":                 "\\spadesuit",
  "♡":                 "\\heartsuit",
  "♢":               "\\diamondsuit",
  "♣":                  "\\clubsuit",
  "♤":              "\\varspadesuit",
  "♥":              "\\varheartsuit",
  "♦":            "\\vardiamondsuit",
  "♧":               "\\varclubsuit",
  "♩":               "\\quarternote",
  "♪":                "\\eighthnote",
  "♫":                  "\\twonotes",
  "♬":             "\\sixteenthnote",
  "♭":                      "\\flat",
  "♮":                   "\\natural",
  "♯":                     "\\sharp",
  "♻":                   "\\recycle",
  "♾":                  "\\acidfree",
  "⚀":                     "\\dicei",
  "⚁":                    "\\diceii",
  "⚂":                   "\\diceiii",
  "⚃":                    "\\diceiv",
  "⚄":                     "\\dicev",
  "⚅":                    "\\dicevi",
  "⚆":           "\\circledrightdot",
  "⚇":            "\\circledtwodots",
  "⚈":      "\\blackcircledrightdot",
  "⚉":       "\\blackcircledtwodots",
  "⚓":                    "\\anchor",
  "⚔":                    "\\swords",
  "⚠":                   "\\warning",
  "⚥":             "\\Hermaphrodite",
  "⚪":                   "\\medcirc",
  "⚫":                 "\\medbullet",
  "⚬":             "\\mdsmwhtcircle",
  "⚲":                    "\\neuter",
  "✎":                    "\\pencil",
  "✓":                 "\\checkmark",
  "✗":                   "\\ballotx",
  "✠":                   "\\maltese",
  "✪":               "\\circledstar",
  "✶":                   "\\varstar",
  "✽":              "\\dingasterisk",
  "〔":                   "\\lbrbrak",
  "〕":                   "\\rbrbrak",
  "➛":             "\\draftingarrow",
  "➢":               "\\arrowbullet",
  "⟀":               "\\threedangle",
  "⟁":      "\\whiteinwhitetriangle",
  "⟂":                      "\\perp",
  "⟃":                "\\subsetcirc",
  "⟄":                "\\supsetcirc",
  "⟅":                      "\\Lbag",
  "⟆":                      "\\Rbag",
  "⟇":                    "\\veedot",
  "⟈":                  "\\bsolhsub",
  "⟉":                   "\\suphsol",
  "⟌":              "\\longdivision",
  "⟐":                "\\Diamonddot",
  "⟑":                  "\\wedgedot",
  "⟒":                      "\\upin",
  "⟓":                  "\\pullback",
  "⟔":                   "\\pushout",
  "⟕":             "\\leftouterjoin",
  "⟖":            "\\rightouterjoin",
  "⟗":             "\\fullouterjoin",
  "⟘":                    "\\bigbot",
  "⟙":                    "\\bigtop",
  "⟚":                 "\\DashVDash",
  "⟛":                 "\\dashVdash",
  "⟜":               "\\multimapinv",
  "⟝":                 "\\vlongdash",
  "⟞":                 "\\longdashv",
  "⟟":                    "\\cirbot",
  "⟠":              "\\lozengeminus",
  "⟡":            "\\concavediamond",
  "⟢":    "\\concavediamondtickleft",
  "⟣":   "\\concavediamondtickright",
  "⟤":       "\\whitesquaretickleft",
  "⟥":      "\\whitesquaretickright",
  "⟦":                 "\\llbracket",
  "⟧":                 "\\rrbracket",
  "⟨":                    "\\langle",
  "⟩":                    "\\rangle",
  "⟪":                      "\\lang",
  "⟫":                      "\\rang",
  "〘":                   "\\Lbrbrak",
  "〙":                   "\\Rbrbrak",
  "⟮":                    "\\lgroup",
  "⟯":                    "\\rgroup",
  "⟰":                  "\\UUparrow",
  "⟱":                "\\DDownarrow",
  "⟲":         "\\acwgapcirclearrow",
  "⟳":          "\\cwgapcirclearrow",
  "⟴":         "\\rightarrowonoplus",
  "⟵":             "\\longleftarrow",
  "⟶":            "\\longrightarrow",
  "⟷":        "\\longleftrightarrow",
  "⟸":             "\\Longleftarrow",
  "⟹":            "\\Longrightarrow",
  "⟺":        "\\Longleftrightarrow",
  "⟻":              "\\longmapsfrom",
  "⟼":                "\\longmapsto",
  "⟽":              "\\Longmapsfrom",
  "⟾":                "\\Longmapsto",
  "⟿":       "\\longrightsquigarrow",
  "⤀":                      "\\psur",
  "⤁":       "\\nVtwoheadrightarrow",
  "⤂":               "\\nvLeftarrow",
  "⤃":              "\\nvRightarrow",
  "⤄":          "\\nvLeftrightarrow",
  "⤅":             "\\twoheadmapsto",
  "⤆":                  "\\Mapsfrom",
  "⤇":                    "\\Mapsto",
  "⤈":           "\\downarrowbarred",
  "⤉":             "\\uparrowbarred",
  "⤊":                  "\\Uuparrow",
  "⤋":                "\\Ddownarrow",
  "⤌":               "\\leftbkarrow",
  "⤍":              "\\rightbkarrow",
  "⤎":              "\\leftdbkarrow",
  "⤏":                   "\\dbkarow",
  "⤐":                  "\\drbkarow",
  "⤑":             "\\rightdotarrow",
  "⤒":                "\\UpArrowBar",
  "⤓":              "\\DownArrowBar",
  "⤔":                      "\\pinj",
  "⤕":                      "\\finj",
  "⤖":                       "\\bij",
  "⤗":   "\\nvtwoheadrightarrowtail",
  "⤘":   "\\nVtwoheadrightarrowtail",
  "⤙":                  "\\lefttail",
  "⤚":                 "\\righttail",
  "⤛":               "\\leftdbltail",
  "⤜":              "\\rightdbltail",
  "⤝":          "\\diamondleftarrow",
  "⤞":         "\\rightarrowdiamond",
  "⤟":       "\\diamondleftarrowbar",
  "⤠":      "\\barrightarrowdiamond",
  "⤡":                 "\\nwsearrow",
  "⤢":                 "\\neswarrow",
  "⤣":                 "\\hknwarrow",
  "⤤":                 "\\hknearrow",
  "⤥":                  "\\hksearow",
  "⤦":                  "\\hkswarow",
  "⤧":                      "\\tona",
  "⤨":                      "\\toea",
  "⤩":                      "\\tosa",
  "⤪":                      "\\towa",
  "⤫":              "\\rdiagovfdiag",
  "⤬":              "\\fdiagovrdiag",
  "⤭":               "\\seovnearrow",
  "⤮":               "\\neovsearrow",
  "⤯":            "\\fdiagovnearrow",
  "⤰":            "\\rdiagovsearrow",
  "⤱":               "\\neovnwarrow",
  "⤲":               "\\nwovnearrow",
  "⤳":                   "\\leadsto",
  "⤴":         "\\uprightcurvearrow",
  "⤵":      "\\downrightcurvedarrow",
  "⤶":       "\\leftdowncurvedarrow",
  "⤷":      "\\rightdowncurvedarrow",
  "⤸":           "\\cwrightarcarrow",
  "⤹":           "\\acwleftarcarrow",
  "⤺":           "\\acwoverarcarrow",
  "⤻":          "\\acwunderarcarrow",
  "⤼":      "\\curvearrowrightminus",
  "⤽":        "\\curvearrowleftplus",
  "⤾":         "\\cwundercurvearrow",
  "⤿":        "\\ccwundercurvearrow",
  "⥀":            "\\acwcirclearrow",
  "⥁":             "\\cwcirclearrow",
  "⥂":  "\\rightarrowshortleftarrow",
  "⥃":  "\\leftarrowshortrightarrow",
  "⥄":  "\\shortrightarrowleftarrow",
  "⥅":            "\\rightarrowplus",
  "⥆":             "\\leftarrowplus",
  "⥇":               "\\rightarrowx",
  "⥈":      "\\leftrightarrowcircle",
  "⥉":      "\\twoheaduparrowcircle",
  "⥊":          "\\leftrightharpoon",
  "⥋":          "\\rightleftharpoon",
  "⥌":    "\\updownharpoonrightleft",
  "⥍":    "\\updownharpoonleftright",
  "⥎":        "\\leftrightharpoonup",
  "⥏":        "\\rightupdownharpoon",
  "⥐":      "\\leftrightharpoondown",
  "⥑":         "\\leftupdownharpoon",
  "⥒":             "\\LeftVectorBar",
  "⥓":            "\\RightVectorBar",
  "⥔":          "\\RightUpVectorBar",
  "⥕":        "\\RightDownVectorBar",
  "⥖":         "\\DownLeftVectorBar",
  "⥗":        "\\DownRightVectorBar",
  "⥘":           "\\LeftUpVectorBar",
  "⥙":         "\\LeftDownVectorBar",
  "⥚":             "\\LeftTeeVector",
  "⥛":            "\\RightTeeVector",
  "⥜":          "\\RightUpTeeVector",
  "⥝":        "\\RightDownTeeVector",
  "⥞":         "\\DownLeftTeeVector",
  "⥟":        "\\DownRightTeeVector",
  "⥠":           "\\LeftUpTeeVector",
  "⥡":         "\\LeftDownTeeVector",
  "⥢":          "\\leftleftharpoons",
  "⥣":              "\\upupharpoons",
  "⥤":        "\\rightrightharpoons",
  "⥥":          "\\downdownharpoons",
  "⥦":       "\\leftrightharpoonsup",
  "⥧":     "\\leftrightharpoonsdown",
  "⥨":       "\\rightleftharpoonsup",
  "⥩":     "\\rightleftharpoonsdown",
  "⥪":            "\\leftbarharpoon",
  "⥫":            "\\barleftharpoon",
  "⥬":           "\\rightbarharpoon",
  "⥭":           "\\barrightharpoon",
  "⥮":            "\\updownharpoons",
  "⥯":            "\\downupharpoons",
  "⥰":                "\\rightimply",
  "⥱":           "\\equalrightarrow",
  "⥲":         "\\similarrightarrow",
  "⥳":          "\\leftarrowsimilar",
  "⥴":         "\\rightarrowsimilar",
  "⥵":          "\\rightarrowapprox",
  "⥶":                    "\\ltlarr",
  "⥷":             "\\leftarrowless",
  "⥸":                    "\\gtrarr",
  "⥹":                   "\\subrarr",
  "⥺":           "\\leftarrowsubset",
  "⥻":                   "\\suplarr",
  "⥼":                  "\\strictfi",
  "⥽":                  "\\strictif",
  "⥾":                "\\upfishtail",
  "⥿":              "\\downfishtail",
  "⦀":                      "\\VERT",
  "⦁":                      "\\spot",
  "⦂":                 "\\typecolon",
  "⦃":                    "\\lBrace",
  "⦄":                    "\\rBrace",
  "⦅":                    "\\Lparen",
  "⦆":                    "\\Rparen",
  "⦇":                      "\\limg",
  "⦈":                      "\\rimg",
  "⦉":                     "\\lblot",
  "⦊":                     "\\rblot",
  "⦋":                "\\lbrackubar",
  "⦌":                "\\rbrackubar",
  "⦍":              "\\lbrackultick",
  "⦎":              "\\rbracklrtick",
  "⦏":              "\\lbracklltick",
  "⦐":              "\\rbrackurtick",
  "⦑":                 "\\langledot",
  "⦒":                 "\\rangledot",
  "⦓":                "\\lparenless",
  "⦔":                 "\\rparengtr",
  "⦕":                 "\\Lparengtr",
  "⦖":                "\\Rparenless",
  "⦗":                "\\lblkbrbrak",
  "⦘":                "\\rblkbrbrak",
  "⦙":                 "\\fourvdots",
  "⦚":                   "\\vzigzag",
  "⦛":         "\\measuredangleleft",
  "⦜":             "\\rightanglesqr",
  "⦝":            "\\rightanglemdot",
  "⦞":                    "\\angles",
  "⦟":                    "\\angdnr",
  "⦠":                    "\\gtlpar",
  "⦡":          "\\sphericalangleup",
  "⦢":                 "\\turnangle",
  "⦣":                  "\\revangle",
  "⦤":                 "\\angleubar",
  "⦥":              "\\revangleubar",
  "⦦":             "\\wideangledown",
  "⦧":               "\\wideangleup",
  "⦨":           "\\measanglerutone",
  "⦩":           "\\measanglelutonw",
  "⦪":           "\\measanglerdtose",
  "⦫":           "\\measangleldtosw",
  "⦬":           "\\measangleurtone",
  "⦭":           "\\measangleultonw",
  "⦮":           "\\measangledrtose",
  "⦯":           "\\measangledltosw",
  "⦰":               "\\revemptyset",
  "⦱":              "\\emptysetobar",
  "⦲":             "\\emptysetocirc",
  "⦳":              "\\emptysetoarr",
  "⦴":             "\\emptysetoarrl",
  "⦵":                "\\circlehbar",
  "⦶":               "\\circledvert",
  "⦷":           "\\circledparallel",
  "⦸":             "\\circledbslash",
  "⦹":                     "\\operp",
  "⦺":                      "\\obot",
  "⦻":                   "\\olcross",
  "⦼":              "\\odotslashdot",
  "⦽":           "\\uparrowoncircle",
  "⦾":        "\\circledwhitebullet",
  "⦿":             "\\circledbullet",
  "⧀":               "\\circledless",
  "⧁":                "\\circledgtr",
  "⧂":                   "\\cirscir",
  "⧃":                      "\\cirE",
  "⧄":                  "\\boxslash",
  "⧅":                 "\\boxbslash",
  "⧆":                    "\\boxast",
  "⧇":                 "\\boxcircle",
  "⧈":                    "\\boxbox",
  "⧉":                  "\\boxonbox",
  "⧊":              "\\triangleodot",
  "⧋":              "\\triangleubar",
  "⧌":                 "\\triangles",
  "⧍":            "\\triangleserifs",
  "⧎":                  "\\rtriltri",
  "⧏":           "\\LeftTriangleBar",
  "⧐":          "\\RightTriangleBar",
  "⧑":                  "\\lfbowtie",
  "⧒":                  "\\rfbowtie",
  "⧓":                   "\\fbowtie",
  "⧔":                   "\\lftimes",
  "⧕":                   "\\rftimes",
  "⧖":                 "\\hourglass",
  "⧗":            "\\blackhourglass",
  "⧘":                  "\\lvzigzag",
  "⧙":                  "\\rvzigzag",
  "⧚":                  "\\Lvzigzag",
  "⧛":                  "\\Rvzigzag",
  "⧜":                    "\\iinfin",
  "⧝":                  "\\tieinfty",
  "⧞":                   "\\nvinfty",
  "⧟":              "\\multimapboth",
  "⧠":                    "\\laplac",
  "⧡":              "\\lrtriangleeq",
  "⧢":                   "\\shuffle",
  "⧣":                    "\\eparsl",
  "⧤":                  "\\smeparsl",
  "⧥":                  "\\eqvparsl",
  "⧦":               "\\gleichstark",
  "⧧":                   "\\thermod",
  "⧨":     "\\downtriangleleftblack",
  "⧩":    "\\downtrianglerightblack",
  "⧪":     "\\blackdiamonddownarrow",
  "⧫":              "\\blacklozenge",
  "⧬":           "\\circledownarrow",
  "⧭":      "\\blackcircledownarrow",
  "⧮":              "\\errbarsquare",
  "⧯":         "\\errbarblacksquare",
  "⧰":             "\\errbardiamond",
  "⧱":        "\\errbarblackdiamond",
  "⧲":              "\\errbarcircle",
  "⧳":         "\\errbarblackcircle",
  "⧴":               "\\ruledelayed",
  "⧵":                  "\\setminus",
  "⧶":                      "\\dsol",
  "⧷":                   "\\rsolbar",
  "⧸":                      "\\xsol",
  "⧹":                     "\\zhide",
  "⧺":                "\\doubleplus",
  "⧻":                "\\tripleplus",
  "⧼":               "\\lcurvyangle",
  "⧽":               "\\rcurvyangle",
  "⧾":                     "\\tplus",
  "⧿":                    "\\tminus",
  "⨀":                   "\\bigodot",
  "⨁":                  "\\bigoplus",
  "⨂":                 "\\bigotimes",
  "⨃":                 "\\bigcupdot",
  "⨄":                  "\\biguplus",
  "⨅":                  "\\bigsqcap",
  "⨆":                  "\\bigsqcup",
  "⨇":                 "\\conjquant",
  "⨈":                 "\\disjquant",
  "⨉":                   "\\varprod",
  "⨊":                 "\\modtwosum",
  "⨋":                    "\\sumint",
  "⨌":                    "\\iiiint",
  "⨍":                    "\\intbar",
  "⨎":                    "\\intBar",
  "⨏":                      "\\fint",
  "⨐":                  "\\cirfnint",
  "⨑":                     "\\awint",
  "⨒":                  "\\rppolint",
  "⨓":                  "\\scpolint",
  "⨔":                   "\\npolint",
  "⨕":                  "\\pointint",
  "⨖":                     "\\sqint",
  "⨗":                  "\\intlarhk",
  "⨘":                      "\\intx",
  "⨙":                    "\\intcap",
  "⨚":                    "\\intcup",
  "⨛":                     "\\upint",
  "⨜":                    "\\lowint",
  "⨝":                      "\\Join",
  "⨞":           "\\bigtriangleleft",
  "⨟":                      "\\zcmp",
  "⨠":                     "\\zpipe",
  "⨡":                  "\\zproject",
  "⨢":                  "\\ringplus",
  "⨣":                   "\\plushat",
  "⨤":                   "\\simplus",
  "⨥":                   "\\plusdot",
  "⨦":                   "\\plussim",
  "⨧":                "\\plussubtwo",
  "⨨":                  "\\plustrif",
  "⨩":                "\\commaminus",
  "⨪":                  "\\minusdot",
  "⨫":                "\\minusfdots",
  "⨬":                "\\minusrdots",
  "⨭":                "\\opluslhrim",
  "⨮":                "\\oplusrhrim",
  "⨯":                  "\\vectimes",
  "⨰":                  "\\dottimes",
  "⨱":                  "\\timesbar",
  "⨲":                    "\\btimes",
  "⨳":                "\\smashtimes",
  "⨴":               "\\otimeslhrim",
  "⨵":               "\\otimesrhrim",
  "⨶":                 "\\otimeshat",
  "⨷":                    "\\Otimes",
  "⨸":                      "\\odiv",
  "⨹":              "\\triangleplus",
  "⨺":             "\\triangleminus",
  "⨻":             "\\triangletimes",
  "⨼":                   "\\intprod",
  "⨽":                  "\\intprodr",
  "⨾":                      "\\fcmp",
  "⨿":                     "\\amalg",
  "⩀":                    "\\capdot",
  "⩁":                    "\\uminus",
  "⩂":                    "\\barcup",
  "⩃":                    "\\barcap",
  "⩄":                  "\\capwedge",
  "⩅":                    "\\cupvee",
  "⩆":                "\\cupovercap",
  "⩇":                "\\capovercup",
  "⩈":                 "\\cupbarcap",
  "⩉":                 "\\capbarcup",
  "⩊":                   "\\twocups",
  "⩋":                   "\\twocaps",
  "⩌":              "\\closedvarcup",
  "⩍":              "\\closedvarcap",
  "⩎":                     "\\Sqcap",
  "⩏":                     "\\Sqcup",
  "⩐":     "\\closedvarcupsmashprod",
  "⩑":                 "\\wedgeodot",
  "⩒":                   "\\veeodot",
  "⩓":                     "\\Wedge",
  "⩔":                       "\\Vee",
  "⩕":              "\\wedgeonwedge",
  "⩖":                  "\\veeonvee",
  "⩗":              "\\bigslopedvee",
  "⩘":            "\\bigslopedwedge",
  "⩙":                "\\veeonwedge",
  "⩚":              "\\wedgemidvert",
  "⩛":                "\\veemidvert",
  "⩜":               "\\midbarwedge",
  "⩝":                 "\\midbarvee",
  "⩞":            "\\doublebarwedge",
  "⩟":                  "\\wedgebar",
  "⩠":            "\\wedgedoublebar",
  "⩡":                 "\\varveebar",
  "⩢":              "\\doublebarvee",
  "⩣":              "\\veedoublebar",
  "⩤":                      "\\dsub",
  "⩥":                      "\\rsub",
  "⩦":                     "\\eqdot",
  "⩧":                  "\\dotequiv",
  "⩨":                 "\\equivVert",
  "⩩":                "\\equivVvert",
  "⩪":                    "\\dotsim",
  "⩫":                  "\\simrdots",
  "⩬":               "\\simminussim",
  "⩭":                   "\\congdot",
  "⩮":                     "\\asteq",
  "⩯":                 "\\hatapprox",
  "⩰":                 "\\approxeqq",
  "⩱":                   "\\eqqplus",
  "⩲":                   "\\pluseqq",
  "⩳":                    "\\eqqsim",
  "⩴":                  "\\Coloneqq",
  "⩵":                     "\\Equal",
  "⩶":                      "\\Same",
  "⩷":                   "\\ddotseq",
  "⩸":                   "\\equivDD",
  "⩹":                     "\\ltcir",
  "⩺":                     "\\gtcir",
  "⩻":                   "\\ltquest",
  "⩼":                   "\\gtquest",
  "⩽":                  "\\leqslant",
  "⩾":                  "\\geqslant",
  "⩿":                    "\\lesdot",
  "⪀":                    "\\gesdot",
  "⪁":                   "\\lesdoto",
  "⪂":                   "\\gesdoto",
  "⪃":                  "\\lesdotor",
  "⪄":                  "\\gesdotol",
  "⪅":                "\\lessapprox",
  "⪆":                 "\\gtrapprox",
  "⪇":                      "\\lneq",
  "⪈":                      "\\gneq",
  "⪉":                  "\\lnapprox",
  "⪊":                  "\\gnapprox",
  "⪋":                "\\lesseqqgtr",
  "⪌":                "\\gtreqqless",
  "⪍":                     "\\lsime",
  "⪎":                     "\\gsime",
  "⪏":                     "\\lsimg",
  "⪐":                     "\\gsiml",
  "⪑":                       "\\lgE",
  "⪒":                       "\\glE",
  "⪓":                    "\\lesges",
  "⪔":                    "\\gesles",
  "⪕":               "\\eqslantless",
  "⪖":                "\\eqslantgtr",
  "⪗":                    "\\elsdot",
  "⪘":                    "\\egsdot",
  "⪙":                   "\\eqqless",
  "⪚":                    "\\eqqgtr",
  "⪛":              "\\eqqslantless",
  "⪜":               "\\eqqslantgtr",
  "⪝":                   "\\simless",
  "⪞":                    "\\simgtr",
  "⪟":                     "\\simlE",
  "⪠":                     "\\simgE",
  "⪡":            "\\NestedLessLess",
  "⪢":      "\\NestedGreaterGreater",
  "⪣":    "\\partialmeetcontraction",
  "⪤":                       "\\glj",
  "⪥":                       "\\gla",
  "⪦":                 "\\leftslice",
  "⪧":                "\\rightslice",
  "⪨":                     "\\lescc",
  "⪩":                     "\\gescc",
  "⪪":                       "\\smt",
  "⪫":                       "\\lat",
  "⪬":                      "\\smte",
  "⪭":                      "\\late",
  "⪮":                   "\\bumpeqq",
  "⪯":                    "\\preceq",
  "⪰":                    "\\succeq",
  "⪱":                   "\\precneq",
  "⪲":                   "\\succneq",
  "⪳":                   "\\preceqq",
  "⪴":                   "\\succeqq",
  "⪵":                  "\\precneqq",
  "⪶":                  "\\succneqq",
  "⪷":                "\\precapprox",
  "⪸":                "\\succapprox",
  "⪹":               "\\precnapprox",
  "⪺":               "\\succnapprox",
  "⪻":                   "\\llcurly",
  "⪼":                   "\\ggcurly",
  "⪽":                 "\\subsetdot",
  "⪾":                 "\\supsetdot",
  "⪿":                "\\subsetplus",
  "⫀":                "\\supsetplus",
  "⫁":                   "\\submult",
  "⫂":                   "\\supmult",
  "⫃":                   "\\subedot",
  "⫄":                   "\\supedot",
  "⫅":                 "\\subseteqq",
  "⫆":                 "\\supseteqq",
  "⫇":                    "\\subsim",
  "⫈":                    "\\supsim",
  "⫉":              "\\subsetapprox",
  "⫊":              "\\supsetapprox",
  "⫋":                "\\subsetneqq",
  "⫌":                "\\supsetneqq",
  "⫍":                   "\\lsqhook",
  "⫎":                   "\\rsqhook",
  "⫏":                      "\\csub",
  "⫐":                      "\\csup",
  "⫑":                     "\\csube",
  "⫒":                     "\\csupe",
  "⫓":                    "\\subsup",
  "⫔":                    "\\supsub",
  "⫕":                    "\\subsub",
  "⫖":                    "\\supsup",
  "⫗":                   "\\suphsub",
  "⫘":                   "\\supdsub",
  "⫙":                     "\\forkv",
  "⫚":                   "\\topfork",
  "⫛":                      "\\mlcp",
  "⫝̸":                     "\\forks",
  "⫝":                  "\\forksnot",
  "⫞":             "\\shortlefttack",
  "⫟":             "\\shortdowntack",
  "⫠":               "\\shortuptack",
  "⫡":                     "\\perps",
  "⫢":                    "\\vDdash",
  "⫣":                     "\\dashV",
  "⫤":                     "\\Dashv",
  "⫥":                     "\\DashV",
  "⫦":                  "\\varVdash",
  "⫧":                      "\\Barv",
  "⫨":                      "\\vBar",
  "⫩":                     "\\vBarv",
  "⫪":                       "\\Top",
  "⫫":                       "\\Bot",
  "⫬":                       "\\Not",
  "⫭":                      "\\bNot",
  "⫮":                   "\\revnmid",
  "⫯":                    "\\cirmid",
  "⫰":                    "\\midcir",
  "⫱":                    "\\topcir",
  "⫲":                     "\\nhpar",
  "⫳":                    "\\parsim",
  "⫴":                "\\interleave",
  "⫵":                   "\\nhVvert",
  "⫶":             "\\threedotcolon",
  "⫷":                   "\\lllnest",
  "⫸":                   "\\gggnest",
  "⫹":                 "\\leqqslant",
  "⫺":                 "\\geqqslant",
  "⫻":                   "\\trslash",
  "⫼":             "\\biginterleave",
  "⫽":                    "\\sslash",
  "⫾":                "\\talloblong",
  "⫿":             "\\bigtalloblong",
  "⬑":                          "R?",
  "⬒":            "\\squaretopblack",
  "⬓":            "\\squarebotblack",
  "⬔":             "\\squareurblack",
  "⬕":             "\\squarellblack",
  "⬖":          "\\diamondleftblack",
  "⬗":         "\\diamondrightblack",
  "⬘":           "\\diamondtopblack",
  "⬙":           "\\diamondbotblack",
  "⬚":              "\\dottedsquare",
  "⬝":             "\\vysmblksquare",
  "⬞":             "\\vysmwhtsquare",
  "⬟":             "\\pentagonblack",
  "⬠":                  "\\pentagon",
  "⬡":                "\\varhexagon",
  "⬢":           "\\varhexagonblack",
  "⬣":              "\\hexagonblack",
  "⬤":               "\\lgblkcircle",
  "⬥":              "\\mdblkdiamond",
  "⬦":              "\\mdwhtdiamond",
  "⬧":              "\\mdblklozenge",
  "⬨":              "\\mdwhtlozenge",
  "⬩":              "\\smblkdiamond",
  "⬪":              "\\smblklozenge",
  "⬫":              "\\smwhtlozenge",
  "⬬":               "\\blkhorzoval",
  "⬭":               "\\whthorzoval",
  "⬮":               "\\blkvertoval",
  "⬯":               "\\whtvertoval",
  "⬰":         "\\circleonleftarrow",
  "⬱":           "\\leftthreearrows",
  "⬲":          "\\leftarrowonoplus",
  "⬳":        "\\longleftsquigarrow",
  "⬴":        "\\nvtwoheadleftarrow",
  "⬵":        "\\nVtwoheadleftarrow",
  "⬶":           "\\twoheadmapsfrom",
  "⬷":       "\\twoheadleftdbkarrow",
  "⬸":              "\\leftdotarrow",
  "⬹":           "\\nvleftarrowtail",
  "⬺":           "\\nVleftarrowtail",
  "⬻":      "\\twoheadleftarrowtail",
  "⬼":    "\\nvtwoheadleftarrowtail",
  "⬽":    "\\nVtwoheadleftarrowtail",
  "⬾":                "\\leftarrowx",
  "⬿":           "\\leftcurvedarrow",
  "⭀":            "\\equalleftarrow",
  "⭁":         "\\bsimilarleftarrow",
  "⭂":       "\\leftarrowbackapprox",
  "⭃":             "\\rightarrowgtr",
  "⭄":          "\\rightarrowsupset",
  "⭅":                "\\LLeftarrow",
  "⭆":               "\\RRightarrow",
  "⭇":        "\\bsimilarrightarrow",
  "⭈":      "\\rightarrowbackapprox",
  "⭉":          "\\similarleftarrow",
  "⭊":           "\\leftarrowapprox",
  "⭋":         "\\leftarrowbsimilar",
  "⭌":        "\\rightarrowbsimilar",
  "⭐":              "\\medwhitestar",
  "⭑":              "\\medblackstar",
  "⭒":               "\\smwhitestar",
  "⭓":        "\\rightpentagonblack",
  "⭔":             "\\rightpentagon",
  "〒":                "\\postalmark",
  "〰":                   "\\hzigzag",
  "𝐀":                 "\\mathbf{A}",
  "𝐁":                 "\\mathbf{B}",
  "𝐂":                 "\\mathbf{C}",
  "𝐃":                 "\\mathbf{D}",
  "𝐄":                 "\\mathbf{E}",
  "𝐅":                 "\\mathbf{F}",
  "𝐆":                 "\\mathbf{G}",
  "𝐇":                 "\\mathbf{H}",
  "𝐈":                 "\\mathbf{I}",
  "𝐉":                 "\\mathbf{J}",
  "𝐊":                 "\\mathbf{K}",
  "𝐋":                 "\\mathbf{L}",
  "𝐌":                 "\\mathbf{M}",
  "𝐍":                 "\\mathbf{N}",
  "𝐎":                 "\\mathbf{O}",
  "𝐏":                 "\\mathbf{P}",
  "𝐐":                 "\\mathbf{Q}",
  "𝐑":                 "\\mathbf{R}",
  "𝐒":                 "\\mathbf{S}",
  "𝐓":                 "\\mathbf{T}",
  "𝐔":                 "\\mathbf{U}",
  "𝐕":                 "\\mathbf{V}",
  "𝐖":                 "\\mathbf{W}",
  "𝐗":                 "\\mathbf{X}",
  "𝐘":                 "\\mathbf{Y}",
  "𝐙":                 "\\mathbf{Z}",
  "𝐚":                 "\\mathbf{a}",
  "𝐛":                 "\\mathbf{b}",
  "𝐜":                 "\\mathbf{c}",
  "𝐝":                 "\\mathbf{d}",
  "𝐞":                 "\\mathbf{e}",
  "𝐟":                 "\\mathbf{f}",
  "𝐠":                 "\\mathbf{g}",
  "𝐡":                 "\\mathbf{h}",
  "𝐢":                 "\\mathbf{i}",
  "𝐣":                 "\\mathbf{j}",
  "𝐤":                 "\\mathbf{k}",
  "𝐥":                 "\\mathbf{l}",
  "𝐦":                 "\\mathbf{m}",
  "𝐧":                 "\\mathbf{n}",
  "𝐨":                 "\\mathbf{o}",
  "𝐩":                 "\\mathbf{p}",
  "𝐪":                 "\\mathbf{q}",
  "𝐫":                 "\\mathbf{r}",
  "𝐬":                 "\\mathbf{s}",
  "𝐭":                 "\\mathbf{t}",
  "𝐮":                 "\\mathbf{u}",
  "𝐯":                 "\\mathbf{v}",
  "𝐰":                 "\\mathbf{w}",
  "𝐱":                 "\\mathbf{x}",
  "𝐲":                 "\\mathbf{y}",
  "𝐳":                 "\\mathbf{z}",
  "𝑨":               "\\mathbfit{A}",
  "𝑩":               "\\mathbfit{B}",
  "𝑪":               "\\mathbfit{C}",
  "𝑫":               "\\mathbfit{D}",
  "𝑬":               "\\mathbfit{E}",
  "𝑭":               "\\mathbfit{F}",
  "𝑮":               "\\mathbfit{G}",
  "𝑯":               "\\mathbfit{H}",
  "𝑰":               "\\mathbfit{I}",
  "𝑱":               "\\mathbfit{J}",
  "𝑲":               "\\mathbfit{K}",
  "𝑳":               "\\mathbfit{L}",
  "𝑴":               "\\mathbfit{M}",
  "𝑵":               "\\mathbfit{N}",
  "𝑶":               "\\mathbfit{O}",
  "𝑷":               "\\mathbfit{P}",
  "𝑸":               "\\mathbfit{Q}",
  "𝑹":               "\\mathbfit{R}",
  "𝑺":               "\\mathbfit{S}",
  "𝑻":               "\\mathbfit{T}",
  "𝑼":               "\\mathbfit{U}",
  "𝑽":               "\\mathbfit{V}",
  "𝑾":               "\\mathbfit{W}",
  "𝑿":               "\\mathbfit{X}",
  "𝒀":               "\\mathbfit{Y}",
  "𝒁":               "\\mathbfit{Z}",
  "𝒂":               "\\mathbfit{a}",
  "𝒃":               "\\mathbfit{b}",
  "𝒄":               "\\mathbfit{c}",
  "𝒅":               "\\mathbfit{d}",
  "𝒆":               "\\mathbfit{e}",
  "𝒇":               "\\mathbfit{f}",
  "𝒈":               "\\mathbfit{g}",
  "𝒉":               "\\mathbfit{h}",
  "𝒊":               "\\mathbfit{i}",
  "𝒋":               "\\mathbfit{j}",
  "𝒌":               "\\mathbfit{k}",
  "𝒍":               "\\mathbfit{l}",
  "𝒎":               "\\mathbfit{m}",
  "𝒏":               "\\mathbfit{n}",
  "𝒐":               "\\mathbfit{o}",
  "𝒑":               "\\mathbfit{p}",
  "𝒒":               "\\mathbfit{q}",
  "𝒓":               "\\mathbfit{r}",
  "𝒔":               "\\mathbfit{s}",
  "𝒕":               "\\mathbfit{t}",
  "𝒖":               "\\mathbfit{u}",
  "𝒗":               "\\mathbfit{v}",
  "𝒘":               "\\mathbfit{w}",
  "𝒙":               "\\mathbfit{x}",
  "𝒚":               "\\mathbfit{y}",
  "𝒛":               "\\mathbfit{z}",
  "𝒜":                "\\mathcal{A}",
  "𝒞":                "\\mathcal{C}",
  "𝒟":                "\\mathcal{D}",
  "𝒢":                "\\mathcal{G}",
  "𝒥":                "\\mathcal{J}",
  "𝒦":                "\\mathcal{K}",
  "𝒩":                "\\mathcal{N}",
  "𝒪":                "\\mathcal{O}",
  "𝒫":                "\\mathcal{P}",
  "𝒬":                "\\mathcal{Q}",
  "𝒮":                "\\mathcal{S}",
  "𝒯":                "\\mathcal{T}",
  "𝒰":                "\\mathcal{U}",
  "𝒱":                "\\mathcal{V}",
  "𝒲":                "\\mathcal{W}",
  "𝒳":                "\\mathcal{X}",
  "𝒴":                "\\mathcal{Y}",
  "𝒵":                "\\mathcal{Z}",
  "𝒶":                "\\mathcal{a}",
  "𝒷":                "\\mathcal{b}",
  "𝒸":                "\\mathcal{c}",
  "𝒹":                "\\mathcal{d}",
  "𝒻":                "\\mathcal{f}",
  "𝒽":                "\\mathcal{h}",
  "𝒾":                "\\mathcal{i}",
  "𝒿":                "\\mathcal{j}",
  "𝓀":                "\\mathcal{k}",
  "𝓁":                "\\mathcal{l}",
  "𝓂":                "\\mathcal{m}",
  "𝓃":                "\\mathcal{n}",
  "𝓅":                "\\mathcal{p}",
  "𝓆":                "\\mathcal{q}",
  "𝓇":                "\\mathcal{r}",
  "𝓈":                "\\mathcal{s}",
  "𝓉":                "\\mathcal{t}",
  "𝓊":                "\\mathcal{u}",
  "𝓋":                "\\mathcal{v}",
  "𝓌":                "\\mathcal{w}",
  "𝓍":                "\\mathcal{x}",
  "𝓎":                "\\mathcal{y}",
  "𝓏":                "\\mathcal{z}",
  "𝓐":                   "\\mbfscrA",
  "𝓑":                   "\\mbfscrB",
  "𝓒":                   "\\mbfscrC",
  "𝓓":                   "\\mbfscrD",
  "𝓔":                   "\\mbfscrE",
  "𝓕":                   "\\mbfscrF",
  "𝓖":                   "\\mbfscrG",
  "𝓗":                   "\\mbfscrH",
  "𝓘":                   "\\mbfscrI",
  "𝓙":                   "\\mbfscrJ",
  "𝓚":                   "\\mbfscrK",
  "𝓛":                   "\\mbfscrL",
  "𝓜":                   "\\mbfscrM",
  "𝓝":                   "\\mbfscrN",
  "𝓞":                   "\\mbfscrO",
  "𝓟":                   "\\mbfscrP",
  "𝓠":                   "\\mbfscrQ",
  "𝓡":                   "\\mbfscrR",
  "𝓢":                   "\\mbfscrS",
  "𝓣":                   "\\mbfscrT",
  "𝓤":                   "\\mbfscrU",
  "𝓥":                   "\\mbfscrV",
  "𝓦":                   "\\mbfscrW",
  "𝓧":                   "\\mbfscrX",
  "𝓨":                   "\\mbfscrY",
  "𝓩":                   "\\mbfscrZ",
  "𝓪":                   "\\mbfscra",
  "𝓫":                   "\\mbfscrb",
  "𝓬":                   "\\mbfscrc",
  "𝓭":                   "\\mbfscrd",
  "𝓮":                   "\\mbfscre",
  "𝓯":                   "\\mbfscrf",
  "𝓰":                   "\\mbfscrg",
  "𝓱":                   "\\mbfscrh",
  "𝓲":                   "\\mbfscri",
  "𝓳":                   "\\mbfscrj",
  "𝓴":                   "\\mbfscrk",
  "𝓵":                   "\\mbfscrl",
  "𝓶":                   "\\mbfscrm",
  "𝓷":                   "\\mbfscrn",
  "𝓸":                   "\\mbfscro",
  "𝓹":                   "\\mbfscrp",
  "𝓺":                   "\\mbfscrq",
  "𝓻":                   "\\mbfscrr",
  "𝓼":                   "\\mbfscrs",
  "𝓽":                   "\\mbfscrt",
  "𝓾":                   "\\mbfscru",
  "𝓿":                   "\\mbfscrv",
  "𝔀":                   "\\mbfscrw",
  "𝔁":                   "\\mbfscrx",
  "𝔂":                   "\\mbfscry",
  "𝔃":                   "\\mbfscrz",
  "𝔄":               "\\mathfrak{A}",
  "𝔅":               "\\mathfrak{B}",
  "𝔇":               "\\mathfrak{D}",
  "𝔈":               "\\mathfrak{E}",
  "𝔉":               "\\mathfrak{F}",
  "𝔊":               "\\mathfrak{G}",
  "𝔍":               "\\mathfrak{J}",
  "𝔎":               "\\mathfrak{K}",
  "𝔏":               "\\mathfrak{L}",
  "𝔐":               "\\mathfrak{M}",
  "𝔑":               "\\mathfrak{N}",
  "𝔒":               "\\mathfrak{O}",
  "𝔓":               "\\mathfrak{P}",
  "𝔔":               "\\mathfrak{Q}",
  "𝔖":               "\\mathfrak{S}",
  "𝔗":               "\\mathfrak{T}",
  "𝔘":               "\\mathfrak{U}",
  "𝔙":               "\\mathfrak{V}",
  "𝔚":               "\\mathfrak{W}",
  "𝔛":               "\\mathfrak{X}",
  "𝔜":               "\\mathfrak{Y}",
  "𝔞":               "\\mathfrak{a}",
  "𝔟":               "\\mathfrak{b}",
  "𝔠":               "\\mathfrak{c}",
  "𝔡":               "\\mathfrak{d}",
  "𝔢":               "\\mathfrak{e}",
  "𝔣":               "\\mathfrak{f}",
  "𝔤":               "\\mathfrak{g}",
  "𝔥":               "\\mathfrak{h}",
  "𝔦":               "\\mathfrak{i}",
  "𝔧":               "\\mathfrak{j}",
  "𝔨":               "\\mathfrak{k}",
  "𝔩":               "\\mathfrak{l}",
  "𝔪":               "\\mathfrak{m}",
  "𝔫":               "\\mathfrak{n}",
  "𝔬":               "\\mathfrak{o}",
  "𝔭":               "\\mathfrak{p}",
  "𝔮":               "\\mathfrak{q}",
  "𝔯":               "\\mathfrak{r}",
  "𝔰":               "\\mathfrak{s}",
  "𝔱":               "\\mathfrak{t}",
  "𝔲":               "\\mathfrak{u}",
  "𝔳":               "\\mathfrak{v}",
  "𝔴":               "\\mathfrak{w}",
  "𝔵":               "\\mathfrak{x}",
  "𝔶":               "\\mathfrak{y}",
  "𝔷":               "\\mathfrak{z}",
  "𝔸":                 "\\mathbb{A}",
  "𝔹":                 "\\mathbb{B}",
  "𝔻":                 "\\mathbb{D}",
  "𝔼":                 "\\mathbb{E}",
  "𝔽":                 "\\mathbb{F}",
  "𝔾":                 "\\mathbb{G}",
  "𝕀":                 "\\mathbb{I}",
  "𝕁":                 "\\mathbb{J}",
  "𝕂":                 "\\mathbb{K}",
  "𝕃":                 "\\mathbb{L}",
  "𝕄":                 "\\mathbb{M}",
  "𝕆":                 "\\mathbb{O}",
  "𝕊":                 "\\mathbb{S}",
  "𝕋":                 "\\mathbb{T}",
  "𝕌":                 "\\mathbb{U}",
  "𝕍":                 "\\mathbb{V}",
  "𝕎":                 "\\mathbb{W}",
  "𝕏":                 "\\mathbb{X}",
  "𝕐":                 "\\mathbb{Y}",
  "𝕒":                 "\\mathbb{a}",
  "𝕓":                 "\\mathbb{b}",
  "𝕔":                 "\\mathbb{c}",
  "𝕕":                 "\\mathbb{d}",
  "𝕖":                 "\\mathbb{e}",
  "𝕗":                 "\\mathbb{f}",
  "𝕘":                 "\\mathbb{g}",
  "𝕙":                 "\\mathbb{h}",
  "𝕚":                 "\\mathbb{i}",
  "𝕛":                 "\\mathbb{j}",
  "𝕜":                 "\\mathbb{k}",
  "𝕝":                 "\\mathbb{l}",
  "𝕞":                 "\\mathbb{m}",
  "𝕟":                 "\\mathbb{n}",
  "𝕠":                 "\\mathbb{o}",
  "𝕡":                 "\\mathbb{p}",
  "𝕢":                 "\\mathbb{q}",
  "𝕣":                 "\\mathbb{r}",
  "𝕤":                 "\\mathbb{s}",
  "𝕥":                 "\\mathbb{t}",
  "𝕦":                 "\\mathbb{u}",
  "𝕧":                 "\\mathbb{v}",
  "𝕨":                 "\\mathbb{w}",
  "𝕩":                 "\\mathbb{x}",
  "𝕪":                 "\\mathbb{y}",
  "𝕫":                 "\\mathbb{z}",
  "𝕬":                  "\\mbffrakA",
  "𝕭":                  "\\mbffrakB",
  "𝕮":                  "\\mbffrakC",
  "𝕯":                  "\\mbffrakD",
  "𝕰":                  "\\mbffrakE",
  "𝕱":                  "\\mbffrakF",
  "𝕲":                  "\\mbffrakG",
  "𝕳":                  "\\mbffrakH",
  "𝕴":                  "\\mbffrakI",
  "𝕵":                  "\\mbffrakJ",
  "𝕶":                  "\\mbffrakK",
  "𝕷":                  "\\mbffrakL",
  "𝕸":                  "\\mbffrakM",
  "𝕹":                  "\\mbffrakN",
  "𝕺":                  "\\mbffrakO",
  "𝕻":                  "\\mbffrakP",
  "𝕼":                  "\\mbffrakQ",
  "𝕽":                  "\\mbffrakR",
  "𝕾":                  "\\mbffrakS",
  "𝕿":                  "\\mbffrakT",
  "𝖀":                  "\\mbffrakU",
  "𝖁":                  "\\mbffrakV",
  "𝖂":                  "\\mbffrakW",
  "𝖃":                  "\\mbffrakX",
  "𝖄":                  "\\mbffrakY",
  "𝖅":                  "\\mbffrakZ",
  "𝖆":                  "\\mbffraka",
  "𝖇":                  "\\mbffrakb",
  "𝖈":                  "\\mbffrakc",
  "𝖉":                  "\\mbffrakd",
  "𝖊":                  "\\mbffrake",
  "𝖋":                  "\\mbffrakf",
  "𝖌":                  "\\mbffrakg",
  "𝖍":                  "\\mbffrakh",
  "𝖎":                  "\\mbffraki",
  "𝖏":                  "\\mbffrakj",
  "𝖐":                  "\\mbffrakk",
  "𝖑":                  "\\mbffrakl",
  "𝖒":                  "\\mbffrakm",
  "𝖓":                  "\\mbffrakn",
  "𝖔":                  "\\mbffrako",
  "𝖕":                  "\\mbffrakp",
  "𝖖":                  "\\mbffrakq",
  "𝖗":                  "\\mbffrakr",
  "𝖘":                  "\\mbffraks",
  "𝖙":                  "\\mbffrakt",
  "𝖚":                  "\\mbffraku",
  "𝖛":                  "\\mbffrakv",
  "𝖜":                  "\\mbffrakw",
  "𝖝":                  "\\mbffrakx",
  "𝖞":                  "\\mbffraky",
  "𝖟":                  "\\mbffrakz",
  "𝖠":                 "\\mathsf{A}",
  "𝖡":                 "\\mathsf{B}",
  "𝖢":                 "\\mathsf{C}",
  "𝖣":                 "\\mathsf{D}",
  "𝖤":                 "\\mathsf{E}",
  "𝖥":                 "\\mathsf{F}",
  "𝖦":                 "\\mathsf{G}",
  "𝖧":                 "\\mathsf{H}",
  "𝖨":                 "\\mathsf{I}",
  "𝖩":                 "\\mathsf{J}",
  "𝖪":                 "\\mathsf{K}",
  "𝖫":                 "\\mathsf{L}",
  "𝖬":                 "\\mathsf{M}",
  "𝖭":                 "\\mathsf{N}",
  "𝖮":                 "\\mathsf{O}",
  "𝖯":                 "\\mathsf{P}",
  "𝖰":                 "\\mathsf{Q}",
  "𝖱":                 "\\mathsf{R}",
  "𝖲":                 "\\mathsf{S}",
  "𝖳":                 "\\mathsf{T}",
  "𝖴":                 "\\mathsf{U}",
  "𝖵":                 "\\mathsf{V}",
  "𝖶":                 "\\mathsf{W}",
  "𝖷":                 "\\mathsf{X}",
  "𝖸":                 "\\mathsf{Y}",
  "𝖹":                 "\\mathsf{Z}",
  "𝖺":                 "\\mathsf{a}",
  "𝖻":                 "\\mathsf{b}",
  "𝖼":                 "\\mathsf{c}",
  "𝖽":                 "\\mathsf{d}",
  "𝖾":                 "\\mathsf{e}",
  "𝖿":                 "\\mathsf{f}",
  "𝗀":                 "\\mathsf{g}",
  "𝗁":                 "\\mathsf{h}",
  "𝗂":                 "\\mathsf{i}",
  "𝗃":                 "\\mathsf{j}",
  "𝗄":                 "\\mathsf{k}",
  "𝗅":                 "\\mathsf{l}",
  "𝗆":                 "\\mathsf{m}",
  "𝗇":                 "\\mathsf{n}",
  "𝗈":                 "\\mathsf{o}",
  "𝗉":                 "\\mathsf{p}",
  "𝗊":                 "\\mathsf{q}",
  "𝗋":                 "\\mathsf{r}",
  "𝗌":                 "\\mathsf{s}",
  "𝗍":                 "\\mathsf{t}",
  "𝗎":                 "\\mathsf{u}",
  "𝗏":                 "\\mathsf{v}",
  "𝗐":                 "\\mathsf{w}",
  "𝗑":                 "\\mathsf{x}",
  "𝗒":                 "\\mathsf{y}",
  "𝗓":                 "\\mathsf{z}",
  "𝗔":               "\\mathsfbf{A}",
  "𝗕":               "\\mathsfbf{B}",
  "𝗖":               "\\mathsfbf{C}",
  "𝗗":               "\\mathsfbf{D}",
  "𝗘":               "\\mathsfbf{E}",
  "𝗙":               "\\mathsfbf{F}",
  "𝗚":               "\\mathsfbf{G}",
  "𝗛":               "\\mathsfbf{H}",
  "𝗜":               "\\mathsfbf{I}",
  "𝗝":               "\\mathsfbf{J}",
  "𝗞":               "\\mathsfbf{K}",
  "𝗟":               "\\mathsfbf{L}",
  "𝗠":               "\\mathsfbf{M}",
  "𝗡":               "\\mathsfbf{N}",
  "𝗢":               "\\mathsfbf{O}",
  "𝗣":               "\\mathsfbf{P}",
  "𝗤":               "\\mathsfbf{Q}",
  "𝗥":               "\\mathsfbf{R}",
  "𝗦":               "\\mathsfbf{S}",
  "𝗧":               "\\mathsfbf{T}",
  "𝗨":               "\\mathsfbf{U}",
  "𝗩":               "\\mathsfbf{V}",
  "𝗪":               "\\mathsfbf{W}",
  "𝗫":               "\\mathsfbf{X}",
  "𝗬":               "\\mathsfbf{Y}",
  "𝗭":               "\\mathsfbf{Z}",
  "𝗮":               "\\mathsfbf{a}",
  "𝗯":               "\\mathsfbf{b}",
  "𝗰":               "\\mathsfbf{c}",
  "𝗱":               "\\mathsfbf{d}",
  "𝗲":               "\\mathsfbf{e}",
  "𝗳":               "\\mathsfbf{f}",
  "𝗴":               "\\mathsfbf{g}",
  "𝗵":               "\\mathsfbf{h}",
  "𝗶":               "\\mathsfbf{i}",
  "𝗷":               "\\mathsfbf{j}",
  "𝗸":               "\\mathsfbf{k}",
  "𝗹":               "\\mathsfbf{l}",
  "𝗺":               "\\mathsfbf{m}",
  "𝗻":               "\\mathsfbf{n}",
  "𝗼":               "\\mathsfbf{o}",
  "𝗽":               "\\mathsfbf{p}",
  "𝗾":               "\\mathsfbf{q}",
  "𝗿":               "\\mathsfbf{r}",
  "𝘀":               "\\mathsfbf{s}",
  "𝘁":               "\\mathsfbf{t}",
  "𝘂":               "\\mathsfbf{u}",
  "𝘃":               "\\mathsfbf{v}",
  "𝘄":               "\\mathsfbf{w}",
  "𝘅":               "\\mathsfbf{x}",
  "𝘆":               "\\mathsfbf{y}",
  "𝘇":               "\\mathsfbf{z}",
  "𝘈":               "\\mathsfit{A}",
  "𝘉":               "\\mathsfit{B}",
  "𝘊":               "\\mathsfit{C}",
  "𝘋":               "\\mathsfit{D}",
  "𝘌":               "\\mathsfit{E}",
  "𝘍":               "\\mathsfit{F}",
  "𝘎":               "\\mathsfit{G}",
  "𝘏":               "\\mathsfit{H}",
  "𝘐":               "\\mathsfit{I}",
  "𝘑":               "\\mathsfit{J}",
  "𝘒":               "\\mathsfit{K}",
  "𝘓":               "\\mathsfit{L}",
  "𝘔":               "\\mathsfit{M}",
  "𝘕":               "\\mathsfit{N}",
  "𝘖":               "\\mathsfit{O}",
  "𝘗":               "\\mathsfit{P}",
  "𝘘":               "\\mathsfit{Q}",
  "𝘙":               "\\mathsfit{R}",
  "𝘚":               "\\mathsfit{S}",
  "𝘛":               "\\mathsfit{T}",
  "𝘜":               "\\mathsfit{U}",
  "𝘝":               "\\mathsfit{V}",
  "𝘞":               "\\mathsfit{W}",
  "𝘟":               "\\mathsfit{X}",
  "𝘠":               "\\mathsfit{Y}",
  "𝘡":               "\\mathsfit{Z}",
  "𝘢":               "\\mathsfit{a}",
  "𝘣":               "\\mathsfit{b}",
  "𝘤":               "\\mathsfit{c}",
  "𝘥":               "\\mathsfit{d}",
  "𝘦":               "\\mathsfit{e}",
  "𝘧":               "\\mathsfit{f}",
  "𝘨":               "\\mathsfit{g}",
  "𝘩":               "\\mathsfit{h}",
  "𝘪":               "\\mathsfit{i}",
  "𝘫":               "\\mathsfit{j}",
  "𝘬":               "\\mathsfit{k}",
  "𝘭":               "\\mathsfit{l}",
  "𝘮":               "\\mathsfit{m}",
  "𝘯":               "\\mathsfit{n}",
  "𝘰":               "\\mathsfit{o}",
  "𝘱":               "\\mathsfit{p}",
  "𝘲":               "\\mathsfit{q}",
  "𝘳":               "\\mathsfit{r}",
  "𝘴":               "\\mathsfit{s}",
  "𝘵":               "\\mathsfit{t}",
  "𝘶":               "\\mathsfit{u}",
  "𝘷":               "\\mathsfit{v}",
  "𝘸":               "\\mathsfit{w}",
  "𝘹":               "\\mathsfit{x}",
  "𝘺":               "\\mathsfit{y}",
  "𝘻":               "\\mathsfit{z}",
  "𝘼":             "\\mathsfbfit{A}",
  "𝘽":             "\\mathsfbfit{B}",
  "𝘾":             "\\mathsfbfit{C}",
  "𝘿":             "\\mathsfbfit{D}",
  "𝙀":             "\\mathsfbfit{E}",
  "𝙁":             "\\mathsfbfit{F}",
  "𝙂":             "\\mathsfbfit{G}",
  "𝙃":             "\\mathsfbfit{H}",
  "𝙄":             "\\mathsfbfit{I}",
  "𝙅":             "\\mathsfbfit{J}",
  "𝙆":             "\\mathsfbfit{K}",
  "𝙇":             "\\mathsfbfit{L}",
  "𝙈":             "\\mathsfbfit{M}",
  "𝙉":             "\\mathsfbfit{N}",
  "𝙊":             "\\mathsfbfit{O}",
  "𝙋":             "\\mathsfbfit{P}",
  "𝙌":             "\\mathsfbfit{Q}",
  "𝙍":             "\\mathsfbfit{R}",
  "𝙎":             "\\mathsfbfit{S}",
  "𝙏":             "\\mathsfbfit{T}",
  "𝙐":             "\\mathsfbfit{U}",
  "𝙑":             "\\mathsfbfit{V}",
  "𝙒":             "\\mathsfbfit{W}",
  "𝙓":             "\\mathsfbfit{X}",
  "𝙔":             "\\mathsfbfit{Y}",
  "𝙕":             "\\mathsfbfit{Z}",
  "𝙖":             "\\mathsfbfit{a}",
  "𝙗":             "\\mathsfbfit{b}",
  "𝙘":             "\\mathsfbfit{c}",
  "𝙙":             "\\mathsfbfit{d}",
  "𝙚":             "\\mathsfbfit{e}",
  "𝙛":             "\\mathsfbfit{f}",
  "𝙜":             "\\mathsfbfit{g}",
  "𝙝":             "\\mathsfbfit{h}",
  "𝙞":             "\\mathsfbfit{i}",
  "𝙟":             "\\mathsfbfit{j}",
  "𝙠":             "\\mathsfbfit{k}",
  "𝙡":             "\\mathsfbfit{l}",
  "𝙢":             "\\mathsfbfit{m}",
  "𝙣":             "\\mathsfbfit{n}",
  "𝙤":             "\\mathsfbfit{o}",
  "𝙥":             "\\mathsfbfit{p}",
  "𝙦":             "\\mathsfbfit{q}",
  "𝙧":             "\\mathsfbfit{r}",
  "𝙨":             "\\mathsfbfit{s}",
  "𝙩":             "\\mathsfbfit{t}",
  "𝙪":             "\\mathsfbfit{u}",
  "𝙫":             "\\mathsfbfit{v}",
  "𝙬":             "\\mathsfbfit{w}",
  "𝙭":             "\\mathsfbfit{x}",
  "𝙮":             "\\mathsfbfit{y}",
  "𝙯":             "\\mathsfbfit{z}",
  "𝙰":                 "\\mathtt{A}",
  "𝙱":                 "\\mathtt{B}",
  "𝙲":                 "\\mathtt{C}",
  "𝙳":                 "\\mathtt{D}",
  "𝙴":                 "\\mathtt{E}",
  "𝙵":                 "\\mathtt{F}",
  "𝙶":                 "\\mathtt{G}",
  "𝙷":                 "\\mathtt{H}",
  "𝙸":                 "\\mathtt{I}",
  "𝙹":                 "\\mathtt{J}",
  "𝙺":                 "\\mathtt{K}",
  "𝙻":                 "\\mathtt{L}",
  "𝙼":                 "\\mathtt{M}",
  "𝙽":                 "\\mathtt{N}",
  "𝙾":                 "\\mathtt{O}",
  "𝙿":                 "\\mathtt{P}",
  "𝚀":                 "\\mathtt{Q}",
  "𝚁":                 "\\mathtt{R}",
  "𝚂":                 "\\mathtt{S}",
  "𝚃":                 "\\mathtt{T}",
  "𝚄":                 "\\mathtt{U}",
  "𝚅":                 "\\mathtt{V}",
  "𝚆":                 "\\mathtt{W}",
  "𝚇":                 "\\mathtt{X}",
  "𝚈":                 "\\mathtt{Y}",
  "𝚉":                 "\\mathtt{Z}",
  "𝚊":                 "\\mathtt{a}",
  "𝚋":                 "\\mathtt{b}",
  "𝚌":                 "\\mathtt{c}",
  "𝚍":                 "\\mathtt{d}",
  "𝚎":                 "\\mathtt{e}",
  "𝚏":                 "\\mathtt{f}",
  "𝚐":                 "\\mathtt{g}",
  "𝚑":                 "\\mathtt{h}",
  "𝚒":                 "\\mathtt{i}",
  "𝚓":                 "\\mathtt{j}",
  "𝚔":                 "\\mathtt{k}",
  "𝚕":                 "\\mathtt{l}",
  "𝚖":                 "\\mathtt{m}",
  "𝚗":                 "\\mathtt{n}",
  "𝚘":                 "\\mathtt{o}",
  "𝚙":                 "\\mathtt{p}",
  "𝚚":                 "\\mathtt{q}",
  "𝚛":                 "\\mathtt{r}",
  "𝚜":                 "\\mathtt{s}",
  "𝚝":                 "\\mathtt{t}",
  "𝚞":                 "\\mathtt{u}",
  "𝚟":                 "\\mathtt{v}",
  "𝚠":                 "\\mathtt{w}",
  "𝚡":                 "\\mathtt{x}",
  "𝚢":                 "\\mathtt{y}",
  "𝚣":                 "\\mathtt{z}",
  "𝚨":                  "\\mbfAlpha",
  "𝚩":                   "\\mbfBeta",
  "𝚪":           "\\mathbf{\\Gamma}",
  "𝚫":           "\\mathbf{\\Delta}",
  "𝚬":                "\\mbfEpsilon",
  "𝚭":                   "\\mbfZeta",
  "𝚮":                    "\\mbfEta",
  "𝚯":           "\\mathbf{\\Theta}",
  "𝚰":                   "\\mbfIota",
  "𝚱":                  "\\mbfKappa",
  "𝚲":          "\\mathbf{\\Lambda}",
  "𝚳":                     "\\mbfMu",
  "𝚴":                     "\\mbfNu",
  "𝚵":              "\\mathbf{\\Xi}",
  "𝚶":                "\\mbfOmicron",
  "𝚷":              "\\mathbf{\\Pi}",
  "𝚸":                    "\\mbfRho",
  "𝚹":               "\\mbfvarTheta",
  "𝚺":           "\\mathbf{\\Sigma}",
  "𝚻":                    "\\mbfTau",
  "𝚼":         "\\mathbf{\\Upsilon}",
  "𝚽":             "\\mathbf{\\Phi}",
  "𝚾":                    "\\mbfChi",
  "𝚿":             "\\mathbf{\\Psi}",
  "𝛀":           "\\mathbf{\\Omega}",
  "𝛁":                  "\\mbfnabla",
  "𝛂":           "\\mathbf{\\alpha}",
  "𝛃":            "\\mathbf{\\beta}",
  "𝛄":           "\\mathbf{\\gamma}",
  "𝛅":           "\\mathbf{\\delta}",
  "𝛆":      "\\mathbf{\\varepsilon}",
  "𝛇":            "\\mathbf{\\zeta}",
  "𝛈":             "\\mathbf{\\eta}",
  "𝛉":           "\\mathbf{\\theta}",
  "𝛊":            "\\mathbf{\\iota}",
  "𝛋":           "\\mathbf{\\kappa}",
  "𝛌":          "\\mathbf{\\lambda}",
  "𝛍":              "\\mathbf{\\mu}",
  "𝛎":              "\\mathbf{\\nu}",
  "𝛏":              "\\mathbf{\\xi}",
  "𝛐":                "\\mbfomicron",
  "𝛑":              "\\mathbf{\\pi}",
  "𝛒":             "\\mathbf{\\rho}",
  "𝛓":        "\\mathbf{\\varsigma}",
  "𝛔":           "\\mathbf{\\sigma}",
  "𝛕":             "\\mathbf{\\tau}",
  "𝛖":         "\\mathbf{\\upsilon}",
  "𝛗":          "\\mathbf{\\varphi}",
  "𝛘":             "\\mathbf{\\chi}",
  "𝛙":             "\\mathbf{\\psi}",
  "𝛚":           "\\mathbf{\\omega}",
  "𝛛":                "\\mbfpartial",
  "𝛜":         "\\mathbf{\\epsilon}",
  "𝛝":        "\\mathbf{\\vartheta}",
  "𝛞":               "\\mbfvarkappa",
  "𝛟":             "\\mathbf{\\phi}",
  "𝛠":          "\\mathbf{\\varrho}",
  "𝛡":           "\\mathbf{\\varpi}",
  "𝛢":                  "\\mitAlpha",
  "𝛣":                   "\\mitBeta",
  "𝛦":                "\\mitEpsilon",
  "𝛧":                   "\\mitZeta",
  "𝛨":                    "\\mitEta",
  "𝛪":                   "\\mitIota",
  "𝛫":                  "\\mitKappa",
  "𝛭":                     "\\mitMu",
  "𝛮":                     "\\mitNu",
  "𝛰":                "\\mitOmicron",
  "𝛲":                    "\\mitRho",
  "𝛳":               "\\mitvarTheta",
  "𝛵":                    "\\mitTau",
  "𝛸":                    "\\mitChi",
  "𝛻":                  "\\mitnabla",
  "𝜊":                "\\mitomicron",
  "𝜜":                "\\mbfitAlpha",
  "𝜝":                 "\\mbfitBeta",
  "𝜞":         "\\mathbfit{\\Gamma}",
  "𝜟":         "\\mathbfit{\\Delta}",
  "𝜠":              "\\mbfitEpsilon",
  "𝜡":                 "\\mbfitZeta",
  "𝜢":                  "\\mbfitEta",
  "𝜣":         "\\mathbfit{\\Theta}",
  "𝜤":                 "\\mbfitIota",
  "𝜥":                "\\mbfitKappa",
  "𝜦":        "\\mathbfit{\\Lambda}",
  "𝜧":                   "\\mbfitMu",
  "𝜨":                   "\\mbfitNu",
  "𝜩":            "\\mathbfit{\\Xi}",
  "𝜪":              "\\mbfitOmicron",
  "𝜫":            "\\mathbfit{\\Pi}",
  "𝜬":                  "\\mbfitRho",
  "𝜭":             "\\mbfitvarTheta",
  "𝜮":         "\\mathbfit{\\Sigma}",
  "𝜯":                  "\\mbfitTau",
  "𝜰":       "\\mathbfit{\\Upsilon}",
  "𝜱":           "\\mathbfit{\\Phi}",
  "𝜲":                  "\\mbfitChi",
  "𝜳":           "\\mathbfit{\\Psi}",
  "𝜴":         "\\mathbfit{\\Omega}",
  "𝜵":                "\\mbfitnabla",
  "𝜶":         "\\mathbfit{\\alpha}",
  "𝜷":          "\\mathbfit{\\beta}",
  "𝜸":         "\\mathbfit{\\gamma}",
  "𝜹":         "\\mathbfit{\\delta}",
  "𝜺":    "\\mathbfit{\\varepsilon}",
  "𝜻":          "\\mathbfit{\\zeta}",
  "𝜼":           "\\mathbfit{\\eta}",
  "𝜽":         "\\mathbfit{\\theta}",
  "𝜾":          "\\mathbfit{\\iota}",
  "𝜿":         "\\mathbfit{\\kappa}",
  "𝝀":        "\\mathbfit{\\lambda}",
  "𝝁":            "\\mathbfit{\\mu}",
  "𝝂":            "\\mathbfit{\\nu}",
  "𝝃":            "\\mathbfit{\\xi}",
  "𝝄":              "\\mbfitomicron",
  "𝝅":            "\\mathbfit{\\pi}",
  "𝝆":           "\\mathbfit{\\rho}",
  "𝝇":      "\\mathbfit{\\varsigma}",
  "𝝈":         "\\mathbfit{\\sigma}",
  "𝝉":           "\\mathbfit{\\tau}",
  "𝝊":       "\\mathbfit{\\upsilon}",
  "𝝋":        "\\mathbfit{\\varphi}",
  "𝝌":           "\\mathbfit{\\chi}",
  "𝝍":           "\\mathbfit{\\psi}",
  "𝝎":         "\\mathbfit{\\omega}",
  "𝝏":              "\\mbfitpartial",
  "𝝐":       "\\mathbfit{\\epsilon}",
  "𝝑":      "\\mathbfit{\\vartheta}",
  "𝝒":             "\\mbfitvarkappa",
  "𝝓":           "\\mathbfit{\\phi}",
  "𝝔":        "\\mathbfit{\\varrho}",
  "𝝕":         "\\mathbfit{\\varpi}",
  "𝝖":              "\\mbfsansAlpha",
  "𝝗":               "\\mbfsansBeta",
  "𝝘":         "\\mathsfbf{\\Gamma}",
  "𝝙":         "\\mathsfbf{\\Delta}",
  "𝝚":            "\\mbfsansEpsilon",
  "𝝛":               "\\mbfsansZeta",
  "𝝜":                "\\mbfsansEta",
  "𝝝":         "\\mathsfbf{\\Theta}",
  "𝝞":               "\\mbfsansIota",
  "𝝟":              "\\mbfsansKappa",
  "𝝠":        "\\mathsfbf{\\Lambda}",
  "𝝡":                 "\\mbfsansMu",
  "𝝢":                 "\\mbfsansNu",
  "𝝣":            "\\mathsfbf{\\Xi}",
  "𝝤":            "\\mbfsansOmicron",
  "𝝥":            "\\mathsfbf{\\Pi}",
  "𝝦":                "\\mbfsansRho",
  "𝝧":           "\\mbfsansvarTheta",
  "𝝨":         "\\mathsfbf{\\Sigma}",
  "𝝩":                "\\mbfsansTau",
  "𝝪":       "\\mathsfbf{\\Upsilon}",
  "𝝫":           "\\mathsfbf{\\Phi}",
  "𝝬":                "\\mbfsansChi",
  "𝝭":           "\\mathsfbf{\\Psi}",
  "𝝮":         "\\mathsfbf{\\Omega}",
  "𝝯":              "\\mbfsansnabla",
  "𝝰":         "\\mathsfbf{\\alpha}",
  "𝝱":          "\\mathsfbf{\\beta}",
  "𝝲":         "\\mathsfbf{\\gamma}",
  "𝝳":         "\\mathsfbf{\\delta}",
  "𝝴":    "\\mathsfbf{\\varepsilon}",
  "𝝵":          "\\mathsfbf{\\zeta}",
  "𝝶":           "\\mathsfbf{\\eta}",
  "𝝷":         "\\mathsfbf{\\theta}",
  "𝝸":          "\\mathsfbf{\\iota}",
  "𝝹":         "\\mathsfbf{\\kappa}",
  "𝝺":        "\\mathsfbf{\\lambda}",
  "𝝻":            "\\mathsfbf{\\mu}",
  "𝝼":            "\\mathsfbf{\\nu}",
  "𝝽":            "\\mathsfbf{\\xi}",
  "𝝾":            "\\mbfsansomicron",
  "𝝿":            "\\mathsfbf{\\pi}",
  "𝞀":           "\\mathsfbf{\\rho}",
  "𝞁":      "\\mathsfbf{\\varsigma}",
  "𝞂":         "\\mathsfbf{\\sigma}",
  "𝞃":           "\\mathsfbf{\\tau}",
  "𝞄":       "\\mathsfbf{\\upsilon}",
  "𝞅":        "\\mathsfbf{\\varphi}",
  "𝞆":           "\\mathsfbf{\\chi}",
  "𝞇":           "\\mathsfbf{\\psi}",
  "𝞈":         "\\mathsfbf{\\omega}",
  "𝞉":            "\\mbfsanspartial",
  "𝞊":       "\\mathsfbf{\\epsilon}",
  "𝞋":      "\\mathsfbf{\\vartheta}",
  "𝞌":           "\\mbfsansvarkappa",
  "𝞍":           "\\mathsfbf{\\phi}",
  "𝞎":        "\\mathsfbf{\\varrho}",
  "𝞏":         "\\mathsfbf{\\varpi}",
  "𝞐":            "\\mbfitsansAlpha",
  "𝞑":             "\\mbfitsansBeta",
  "𝞒":       "\\mathsfbfit{\\Gamma}",
  "𝞓":       "\\mathsfbfit{\\Delta}",
  "𝞔":          "\\mbfitsansEpsilon",
  "𝞕":             "\\mbfitsansZeta",
  "𝞖":              "\\mbfitsansEta",
  "𝞗":       "\\mathsfbfit{\\Theta}",
  "𝞘":             "\\mbfitsansIota",
  "𝞙":            "\\mbfitsansKappa",
  "𝞚":      "\\mathsfbfit{\\Lambda}",
  "𝞛":               "\\mbfitsansMu",
  "𝞜":               "\\mbfitsansNu",
  "𝞝":          "\\mathsfbfit{\\Xi}",
  "𝞞":          "\\mbfitsansOmicron",
  "𝞟":          "\\mathsfbfit{\\Pi}",
  "𝞠":              "\\mbfitsansRho",
  "𝞡":         "\\mbfitsansvarTheta",
  "𝞢":       "\\mathsfbfit{\\Sigma}",
  "𝞣":              "\\mbfitsansTau",
  "𝞤":     "\\mathsfbfit{\\Upsilon}",
  "𝞥":         "\\mathsfbfit{\\Phi}",
  "𝞦":              "\\mbfitsansChi",
  "𝞧":         "\\mathsfbfit{\\Psi}",
  "𝞨":       "\\mathsfbfit{\\Omega}",
  "𝞩":            "\\mbfitsansnabla",
  "𝞪":       "\\mathsfbfit{\\alpha}",
  "𝞫":        "\\mathsfbfit{\\beta}",
  "𝞬":       "\\mathsfbfit{\\gamma}",
  "𝞭":       "\\mathsfbfit{\\delta}",
  "𝞮":  "\\mathsfbfit{\\varepsilon}",
  "𝞯":        "\\mathsfbfit{\\zeta}",
  "𝞰":         "\\mathsfbfit{\\eta}",
  "𝞱":       "\\mathsfbfit{\\theta}",
  "𝞲":        "\\mathsfbfit{\\iota}",
  "𝞳":       "\\mathsfbfit{\\kappa}",
  "𝞴":      "\\mathsfbfit{\\lambda}",
  "𝞵":          "\\mathsfbfit{\\mu}",
  "𝞶":          "\\mathsfbfit{\\nu}",
  "𝞷":          "\\mathsfbfit{\\xi}",
  "𝞸":          "\\mbfitsansomicron",
  "𝞹":          "\\mathsfbfit{\\pi}",
  "𝞺":         "\\mathsfbfit{\\rho}",
  "𝞻":    "\\mathsfbfit{\\varsigma}",
  "𝞼":       "\\mathsfbfit{\\sigma}",
  "𝞽":         "\\mathsfbfit{\\tau}",
  "𝞾":     "\\mathsfbfit{\\upsilon}",
  "𝞿":      "\\mathsfbfit{\\varphi}",
  "𝟀":         "\\mathsfbfit{\\chi}",
  "𝟁":         "\\mathsfbfit{\\psi}",
  "𝟂":       "\\mathsfbfit{\\omega}",
  "𝟃":          "\\mbfitsanspartial",
  "𝟄":     "\\mathsfbfit{\\epsilon}",
  "𝟅":    "\\mathsfbfit{\\vartheta}",
  "𝟆":         "\\mbfitsansvarkappa",
  "𝟇":         "\\mathsfbfit{\\phi}",
  "𝟈":      "\\mathsfbfit{\\varrho}",
  "𝟉":       "\\mathsfbfit{\\varpi}",
  "𝟊":                "\\mbfDigamma",
  "𝟋":                "\\mbfdigamma",
  "𝟎":                 "\\mathbf{0}",
  "𝟏":                 "\\mathbf{1}",
  "𝟐":                 "\\mathbf{2}",
  "𝟑":                 "\\mathbf{3}",
  "𝟒":                 "\\mathbf{4}",
  "𝟓":                 "\\mathbf{5}",
  "𝟔":                 "\\mathbf{6}",
  "𝟕":                 "\\mathbf{7}",
  "𝟖":                 "\\mathbf{8}",
  "𝟗":                 "\\mathbf{9}",
  "𝟘":                 "\\mathbb{0}",
  "𝟙":                 "\\mathbb{1}",
  "𝟚":                 "\\mathbb{2}",
  "𝟛":                 "\\mathbb{3}",
  "𝟜":                 "\\mathbb{4}",
  "𝟝":                 "\\mathbb{5}",
  "𝟞":                 "\\mathbb{6}",
  "𝟟":                 "\\mathbb{7}",
  "𝟠":                 "\\mathbb{8}",
  "𝟡":                 "\\mathbb{9}",
  "𝟢":                 "\\mathsf{0}",
  "𝟣":                 "\\mathsf{1}",
  "𝟤":                 "\\mathsf{2}",
  "𝟥":                 "\\mathsf{3}",
  "𝟦":                 "\\mathsf{4}",
  "𝟧":                 "\\mathsf{5}",
  "𝟨":                 "\\mathsf{6}",
  "𝟩":                 "\\mathsf{7}",
  "𝟪":                 "\\mathsf{8}",
  "𝟫":                 "\\mathsf{9}",
  "𝟬":               "\\mathsfbf{0}",
  "𝟭":               "\\mathsfbf{1}",
  "𝟮":               "\\mathsfbf{2}",
  "𝟯":               "\\mathsfbf{3}",
  "𝟰":               "\\mathsfbf{4}",
  "𝟱":               "\\mathsfbf{5}",
  "𝟲":               "\\mathsfbf{6}",
  "𝟳":               "\\mathsfbf{7}",
  "𝟴":               "\\mathsfbf{8}",
  "𝟵":               "\\mathsfbf{9}",
  "𝟶":                 "\\mathtt{0}",
  "𝟷":                 "\\mathtt{1}",
  "𝟸":                 "\\mathtt{2}",
  "𝟹":                 "\\mathtt{3}",
  "𝟺":                 "\\mathtt{4}",
  "𝟻":                 "\\mathtt{5}",
  "𝟼":                 "\\mathtt{6}",
  "𝟽":                 "\\mathtt{7}",
  "𝟾":                 "\\mathtt{8}",
  "𝟿":                 "\\mathtt{9}",
  "⁰":                          "^0",
  "¹":                          "^1",
  "²":                          "^2",
  "³":                          "^3",
  "⁴":                          "^4",
  "⁵":                          "^5",
  "⁶":                          "^6",
  "⁷":                          "^7",
  "⁸":                          "^8",
  "⁹":                          "^9",
  "⁺":                          "^+",
  "⁻":                          "^-",
  "⁼":                          "^=",
  "⁽":                          "^(",
  "⁾":                          "^)",
  "₀":                          "_0",
  "₁":                          "_1",
  "₂":                          "_2",
  "₃":                          "_3",
  "₄":                          "_4",
  "₅":                          "_5",
  "₆":                          "_6",
  "₇":                          "_7",
  "₈":                          "_8",
  "₉":                          "_9",
  "₊":                          "_+",
  "₋":                          "_-",
  "₌":                          "_=",
  "₍":                          "_(",
  "₎":                          "_)",
  "½":                 "\\frac{1}{2}",
  "¼":                 "\\frac{1}{4}",
  "¾":                 "\\frac{3}{4}",
"Α": "\\Alpha",
"Β": "\\Beta",
"Γ": "\\Gamma",
"Δ": "\\Delta",
"Ε": "\\Epsilon",
"Ζ": "\\Zeta",
"Η": "\\Eta",
"Θ": "\\Theta",
"Ι": "\\Iota",
"Κ": "\\Kappa",
"Λ": "\\Lambda",
"Μ": "\\upMu",
"Ν": "\\upNu",
"Ξ": "\\Xi",
"Ο": "\\upOmicron",
"Π": "\\Pi",
"Ρ": "\\Rho",
"Σ": "\\Sigma",
"Τ": "\\Tau",
"Υ": "\\Upsilon",
"Φ": "\\Phi",
"Χ": "\\Chi",
"Ψ": "\\Psi",
"Ω": "\\Omega",
"α": "\\alpha",
"β": "\\beta",
"γ": "\\gamma",
"δ": "\\delta",
"ε": "\\upepsilon",
"ζ": "\\zeta",
"η": "\\eta",
"θ": "\\theta",
"ι": "\\iota",
"κ": "\\kappa",
"λ": "\\lambda",
"μ": "\\mu",
"ν": "\\nu",
"ξ": "\\xi",
"ο": "\\upomicron",
"π": "\\pi",
"ρ": "\\rho",
"ς": "\\varsigma",
"σ": "\\sigma",
"τ": "\\tau",
"υ": "\\upsilon",
"φ": "\\varphi",
"χ": "\\chi",
"ψ": "\\psi",
"ω": "\\omega",
"ϐ": "\\upvarbeta",
"ϑ": "\\vartheta",
"ϕ": "\\phi",
"ϖ": "\\varpi",
"Ϙ": "\\upoldKoppa",
"ϙ": "\\upoldkoppa",
"Ϛ": "\\Stigma",
"ϛ": "\\upstigma",
"Ϝ": "\\Digamma",
"ϝ": "\\digamma",
"Ϟ": "\\Koppa",
"ϟ": "\\upkoppa",
"Ϡ": "\\Sampi",
"ϡ": "\\upsampi",
"ϰ": "\\varkappa",
"ϱ": "\\varrho",
"ϴ": "\\textTheta",
"ϵ": "\\varepsilon",
"϶": "\\backepsilon",
  "↹":  "\\barleftarrowrightarrowba",
        }

    def unicode2latex(text)
      SYMBOLS.each do |k, v| 
        text.gsub!(k.to_s, v)
      end
      text
    end
  end
end
